# MIT LICENSE
#
# Copyright 1997 - 2019 by IXIA Keysight
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"),
# to deal in the Software without restriction, including without limitation
# the rights to use, copy, modify, merge, publish, distribute, sublicense,
# and/or sell copies of the Software, and to permit persons to whom the
# Software is furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in
# all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
# THE SOFTWARE.
from ixnetwork_restpy.base import Base
from ixnetwork_restpy.files import Files


class SwitchPorts(Base):
	"""The SwitchPorts class encapsulates a user managed switchPorts node in the ixnetwork hierarchy.

	An instance of the class can be obtained by accessing the SwitchPorts property from a parent instance.
	The internal properties list will be empty when the property is accessed and is populated from the server using the find method.
	The internal properties list can be managed by the user by using the add and remove methods.
	"""

	_SDM_NAME = 'switchPorts'

	def __init__(self, parent):
		super(SwitchPorts, self).__init__(parent)

	@property
	def AdvertisedFeatures(self):
		"""An instance of the AdvertisedFeatures class.

		Returns:
			obj(ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.openflow.advertisedfeatures.AdvertisedFeatures)

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		from ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.openflow.advertisedfeatures import AdvertisedFeatures
		return AdvertisedFeatures(self)._select()

	@property
	def Config(self):
		"""An instance of the Config class.

		Returns:
			obj(ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.openflow.config.Config)

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		from ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.openflow.config import Config
		return Config(self)._select()

	@property
	def CurrentFeatures(self):
		"""An instance of the CurrentFeatures class.

		Returns:
			obj(ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.openflow.currentfeatures.CurrentFeatures)

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		from ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.openflow.currentfeatures import CurrentFeatures
		return CurrentFeatures(self)._select()

	@property
	def PeerAdvertisedFeatures(self):
		"""An instance of the PeerAdvertisedFeatures class.

		Returns:
			obj(ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.openflow.peeradvertisedfeatures.PeerAdvertisedFeatures)

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		from ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.openflow.peeradvertisedfeatures import PeerAdvertisedFeatures
		return PeerAdvertisedFeatures(self)._select()

	@property
	def State(self):
		"""An instance of the State class.

		Returns:
			obj(ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.openflow.state.State)

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		from ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.openflow.state import State
		return State(self)._select()

	@property
	def SupportedFeatures(self):
		"""An instance of the SupportedFeatures class.

		Returns:
			obj(ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.openflow.supportedfeatures.SupportedFeatures)

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		from ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.openflow.supportedfeatures import SupportedFeatures
		return SupportedFeatures(self)._select()

	@property
	def SwitchPortQueues(self):
		"""An instance of the SwitchPortQueues class.

		Returns:
			obj(ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.openflow.switchportqueues.SwitchPortQueues)

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		from ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.openflow.switchportqueues import SwitchPortQueues
		return SwitchPortQueues(self)

	@property
	def Enabled(self):
		"""If true, the ports in the selected port range are added to the switch.

		Returns:
			bool
		"""
		return self._get_attribute('enabled')
	@Enabled.setter
	def Enabled(self, value):
		self._set_attribute('enabled', value)

	@property
	def EthernetAddress(self):
		"""Indicates the hardware address of the ports in the port range.

		Returns:
			str
		"""
		return self._get_attribute('ethernetAddress')
	@EthernetAddress.setter
	def EthernetAddress(self, value):
		self._set_attribute('ethernetAddress', value)

	@property
	def NumberOfPorts(self):
		"""Specifies the number of ports in a port range.

		Returns:
			number
		"""
		return self._get_attribute('numberOfPorts')
	@NumberOfPorts.setter
	def NumberOfPorts(self, value):
		self._set_attribute('numberOfPorts', value)

	@property
	def PortName(self):
		"""Indicates the name for the switch port interface.

		Returns:
			str
		"""
		return self._get_attribute('portName')
	@PortName.setter
	def PortName(self, value):
		self._set_attribute('portName', value)

	@property
	def PortNumber(self):
		"""Indicates a value that the datapath associates with a physical port.

		Returns:
			str
		"""
		return self._get_attribute('portNumber')
	@PortNumber.setter
	def PortNumber(self, value):
		self._set_attribute('portNumber', value)

	def update(self, Enabled=None, EthernetAddress=None, NumberOfPorts=None, PortName=None, PortNumber=None):
		"""Updates a child instance of switchPorts on the server.

		Args:
			Enabled (bool): If true, the ports in the selected port range are added to the switch.
			EthernetAddress (str): Indicates the hardware address of the ports in the port range.
			NumberOfPorts (number): Specifies the number of ports in a port range.
			PortName (str): Indicates the name for the switch port interface.
			PortNumber (str): Indicates a value that the datapath associates with a physical port.

		Raises:
			ServerError: The server has encountered an uncategorized error condition
		"""
		self._update(locals())

	def add(self, Enabled=None, EthernetAddress=None, NumberOfPorts=None, PortName=None, PortNumber=None):
		"""Adds a new switchPorts node on the server and retrieves it in this instance.

		Args:
			Enabled (bool): If true, the ports in the selected port range are added to the switch.
			EthernetAddress (str): Indicates the hardware address of the ports in the port range.
			NumberOfPorts (number): Specifies the number of ports in a port range.
			PortName (str): Indicates the name for the switch port interface.
			PortNumber (str): Indicates a value that the datapath associates with a physical port.

		Returns:
			self: This instance with all currently retrieved switchPorts data using find and the newly added switchPorts data available through an iterator or index

		Raises:
			ServerError: The server has encountered an uncategorized error condition
		"""
		return self._create(locals())

	def remove(self):
		"""Deletes all the switchPorts data in this instance from server.

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		self._delete()

	def find(self, Enabled=None, EthernetAddress=None, NumberOfPorts=None, PortName=None, PortNumber=None):
		"""Finds and retrieves switchPorts data from the server.

		All named parameters support regex and can be used to selectively retrieve switchPorts data from the server.
		By default the find method takes no parameters and will retrieve all switchPorts data from the server.

		Args:
			Enabled (bool): If true, the ports in the selected port range are added to the switch.
			EthernetAddress (str): Indicates the hardware address of the ports in the port range.
			NumberOfPorts (number): Specifies the number of ports in a port range.
			PortName (str): Indicates the name for the switch port interface.
			PortNumber (str): Indicates a value that the datapath associates with a physical port.

		Returns:
			self: This instance with matching switchPorts data retrieved from the server available through an iterator or index

		Raises:
			ServerError: The server has encountered an uncategorized error condition
		"""
		return self._select(locals())

	def read(self, href):
		"""Retrieves a single instance of switchPorts data from the server.

		Args:
			href (str): An href to the instance to be retrieved

		Returns:
			self: This instance with the switchPorts data from the server available through an iterator or index

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		return self._read(href)

	def SimulatePortUpDown(self):
		"""Executes the simulatePortUpDown operation on the server.

		Exec to simulate port up and down.

			Returns:
				bool: NOT DEFINED

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = { "Arg1": self.href }
		return self._execute('simulatePortUpDown', payload=payload, response_object=None)



# MIT LICENSE
#
# Copyright 1997 - 2019 by IXIA Keysight
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"),
# to deal in the Software without restriction, including without limitation
# the rights to use, copy, modify, merge, publish, distribute, sublicense,
# and/or sell copies of the Software, and to permit persons to whom the
# Software is furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in
# all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
# THE SOFTWARE.
from ixnetwork_restpy.base import Base
from ixnetwork_restpy.files import Files


class FilterPalette(Base):
	"""The FilterPalette class encapsulates a required filterPalette node in the ixnetwork hierarchy.

	An instance of the class can be obtained by accessing the FilterPalette property from a parent instance.
	The internal properties list will contain one and only one set of properties which is populated when the property is accessed.
	"""

	_SDM_NAME = 'filterPalette'

	def __init__(self, parent):
		super(FilterPalette, self).__init__(parent)

	@property
	def DestinationAddress1(self):
		"""Destination address 1.

		Returns:
			str
		"""
		return self._get_attribute('destinationAddress1')
	@DestinationAddress1.setter
	def DestinationAddress1(self, value):
		self._set_attribute('destinationAddress1', value)

	@property
	def DestinationAddress1Mask(self):
		"""The destination address mask.

		Returns:
			str
		"""
		return self._get_attribute('destinationAddress1Mask')
	@DestinationAddress1Mask.setter
	def DestinationAddress1Mask(self, value):
		self._set_attribute('destinationAddress1Mask', value)

	@property
	def DestinationAddress2(self):
		"""Destination address 2.

		Returns:
			str
		"""
		return self._get_attribute('destinationAddress2')
	@DestinationAddress2.setter
	def DestinationAddress2(self, value):
		self._set_attribute('destinationAddress2', value)

	@property
	def DestinationAddress2Mask(self):
		"""Destination address to mask.

		Returns:
			str
		"""
		return self._get_attribute('destinationAddress2Mask')
	@DestinationAddress2Mask.setter
	def DestinationAddress2Mask(self, value):
		self._set_attribute('destinationAddress2Mask', value)

	@property
	def Pattern1(self):
		"""Pattern 1.

		Returns:
			str
		"""
		return self._get_attribute('pattern1')
	@Pattern1.setter
	def Pattern1(self, value):
		self._set_attribute('pattern1', value)

	@property
	def Pattern1Mask(self):
		"""Pattern 1 mask.

		Returns:
			str
		"""
		return self._get_attribute('pattern1Mask')
	@Pattern1Mask.setter
	def Pattern1Mask(self, value):
		self._set_attribute('pattern1Mask', value)

	@property
	def Pattern1Offset(self):
		"""Pattern 1 offset.

		Returns:
			number
		"""
		return self._get_attribute('pattern1Offset')
	@Pattern1Offset.setter
	def Pattern1Offset(self, value):
		self._set_attribute('pattern1Offset', value)

	@property
	def Pattern1OffsetType(self):
		"""The pattern offset type.

		Returns:
			str(fromStartOfFrame|fromStartOfIp|fromStartOfProtocol|fromStartOfSonet)
		"""
		return self._get_attribute('pattern1OffsetType')
	@Pattern1OffsetType.setter
	def Pattern1OffsetType(self, value):
		self._set_attribute('pattern1OffsetType', value)

	@property
	def Pattern2(self):
		"""Patternt 2.

		Returns:
			str
		"""
		return self._get_attribute('pattern2')
	@Pattern2.setter
	def Pattern2(self, value):
		self._set_attribute('pattern2', value)

	@property
	def Pattern2Mask(self):
		"""The pattern mask.

		Returns:
			str
		"""
		return self._get_attribute('pattern2Mask')
	@Pattern2Mask.setter
	def Pattern2Mask(self, value):
		self._set_attribute('pattern2Mask', value)

	@property
	def Pattern2Offset(self):
		"""The offset at which the pattern is located in the packet.

		Returns:
			number
		"""
		return self._get_attribute('pattern2Offset')
	@Pattern2Offset.setter
	def Pattern2Offset(self, value):
		self._set_attribute('pattern2Offset', value)

	@property
	def Pattern2OffsetType(self):
		"""Pattern 2 offset type

		Returns:
			str(fromStartOfFrame|fromStartOfIp|fromStartOfProtocol|fromStartOfSonet)
		"""
		return self._get_attribute('pattern2OffsetType')
	@Pattern2OffsetType.setter
	def Pattern2OffsetType(self, value):
		self._set_attribute('pattern2OffsetType', value)

	@property
	def SourceAddress1(self):
		"""Source address 1.

		Returns:
			str
		"""
		return self._get_attribute('sourceAddress1')
	@SourceAddress1.setter
	def SourceAddress1(self, value):
		self._set_attribute('sourceAddress1', value)

	@property
	def SourceAddress1Mask(self):
		"""Source address 1 mask.

		Returns:
			str
		"""
		return self._get_attribute('sourceAddress1Mask')
	@SourceAddress1Mask.setter
	def SourceAddress1Mask(self, value):
		self._set_attribute('sourceAddress1Mask', value)

	@property
	def SourceAddress2(self):
		"""Source address 2.

		Returns:
			str
		"""
		return self._get_attribute('sourceAddress2')
	@SourceAddress2.setter
	def SourceAddress2(self, value):
		self._set_attribute('sourceAddress2', value)

	@property
	def SourceAddress2Mask(self):
		"""Source address to mask.

		Returns:
			str
		"""
		return self._get_attribute('sourceAddress2Mask')
	@SourceAddress2Mask.setter
	def SourceAddress2Mask(self, value):
		self._set_attribute('sourceAddress2Mask', value)

	def update(self, DestinationAddress1=None, DestinationAddress1Mask=None, DestinationAddress2=None, DestinationAddress2Mask=None, Pattern1=None, Pattern1Mask=None, Pattern1Offset=None, Pattern1OffsetType=None, Pattern2=None, Pattern2Mask=None, Pattern2Offset=None, Pattern2OffsetType=None, SourceAddress1=None, SourceAddress1Mask=None, SourceAddress2=None, SourceAddress2Mask=None):
		"""Updates a child instance of filterPalette on the server.

		Args:
			DestinationAddress1 (str): Destination address 1.
			DestinationAddress1Mask (str): The destination address mask.
			DestinationAddress2 (str): Destination address 2.
			DestinationAddress2Mask (str): Destination address to mask.
			Pattern1 (str): Pattern 1.
			Pattern1Mask (str): Pattern 1 mask.
			Pattern1Offset (number): Pattern 1 offset.
			Pattern1OffsetType (str(fromStartOfFrame|fromStartOfIp|fromStartOfProtocol|fromStartOfSonet)): The pattern offset type.
			Pattern2 (str): Patternt 2.
			Pattern2Mask (str): The pattern mask.
			Pattern2Offset (number): The offset at which the pattern is located in the packet.
			Pattern2OffsetType (str(fromStartOfFrame|fromStartOfIp|fromStartOfProtocol|fromStartOfSonet)): Pattern 2 offset type
			SourceAddress1 (str): Source address 1.
			SourceAddress1Mask (str): Source address 1 mask.
			SourceAddress2 (str): Source address 2.
			SourceAddress2Mask (str): Source address to mask.

		Raises:
			ServerError: The server has encountered an uncategorized error condition
		"""
		self._update(locals())



# MIT LICENSE
#
# Copyright 1997 - 2019 by IXIA Keysight
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"),
# to deal in the Software without restriction, including without limitation
# the rights to use, copy, modify, merge, publish, distribute, sublicense,
# and/or sell copies of the Software, and to permit persons to whom the
# Software is furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in
# all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
# THE SOFTWARE.
from ixnetwork_restpy.base import Base
from ixnetwork_restpy.files import Files


class IsisPseudoInterface(Base):
	"""The IsisPseudoInterface class encapsulates a system managed isisPseudoInterface node in the ixnetwork hierarchy.

	An instance of the class can be obtained by accessing the IsisPseudoInterface property from a parent instance.
	The internal properties list will be empty when the property is accessed and is populated from the server by using the find method.
	"""

	_SDM_NAME = 'isisPseudoInterface'

	def __init__(self, parent):
		super(IsisPseudoInterface, self).__init__(parent)

	@property
	def IsisDcePseudoIfaceAttPoint1Config(self):
		"""An instance of the IsisDcePseudoIfaceAttPoint1Config class.

		Returns:
			obj(ixnetwork_restpy.testplatform.sessions.ixnetwork.topology.isisdcepseudoifaceattpoint1config.IsisDcePseudoIfaceAttPoint1Config)

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		from ixnetwork_restpy.testplatform.sessions.ixnetwork.topology.isisdcepseudoifaceattpoint1config import IsisDcePseudoIfaceAttPoint1Config
		return IsisDcePseudoIfaceAttPoint1Config(self)

	@property
	def IsisDcePseudoIfaceAttPoint2Config(self):
		"""An instance of the IsisDcePseudoIfaceAttPoint2Config class.

		Returns:
			obj(ixnetwork_restpy.testplatform.sessions.ixnetwork.topology.isisdcepseudoifaceattpoint2config.IsisDcePseudoIfaceAttPoint2Config)

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		from ixnetwork_restpy.testplatform.sessions.ixnetwork.topology.isisdcepseudoifaceattpoint2config import IsisDcePseudoIfaceAttPoint2Config
		return IsisDcePseudoIfaceAttPoint2Config(self)

	@property
	def IsisL3PseudoIfaceAttPoint1Config(self):
		"""An instance of the IsisL3PseudoIfaceAttPoint1Config class.

		Returns:
			obj(ixnetwork_restpy.testplatform.sessions.ixnetwork.topology.isisl3pseudoifaceattpoint1config.IsisL3PseudoIfaceAttPoint1Config)

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		from ixnetwork_restpy.testplatform.sessions.ixnetwork.topology.isisl3pseudoifaceattpoint1config import IsisL3PseudoIfaceAttPoint1Config
		return IsisL3PseudoIfaceAttPoint1Config(self)

	@property
	def IsisL3PseudoIfaceAttPoint2Config(self):
		"""An instance of the IsisL3PseudoIfaceAttPoint2Config class.

		Returns:
			obj(ixnetwork_restpy.testplatform.sessions.ixnetwork.topology.isisl3pseudoifaceattpoint2config.IsisL3PseudoIfaceAttPoint2Config)

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		from ixnetwork_restpy.testplatform.sessions.ixnetwork.topology.isisl3pseudoifaceattpoint2config import IsisL3PseudoIfaceAttPoint2Config
		return IsisL3PseudoIfaceAttPoint2Config(self)

	@property
	def IsisSpbPseudoIfaceAttPoint1Config(self):
		"""An instance of the IsisSpbPseudoIfaceAttPoint1Config class.

		Returns:
			obj(ixnetwork_restpy.testplatform.sessions.ixnetwork.topology.isisspbpseudoifaceattpoint1config.IsisSpbPseudoIfaceAttPoint1Config)

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		from ixnetwork_restpy.testplatform.sessions.ixnetwork.topology.isisspbpseudoifaceattpoint1config import IsisSpbPseudoIfaceAttPoint1Config
		return IsisSpbPseudoIfaceAttPoint1Config(self)

	@property
	def IsisSpbPseudoIfaceAttPoint2Config(self):
		"""An instance of the IsisSpbPseudoIfaceAttPoint2Config class.

		Returns:
			obj(ixnetwork_restpy.testplatform.sessions.ixnetwork.topology.isisspbpseudoifaceattpoint2config.IsisSpbPseudoIfaceAttPoint2Config)

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		from ixnetwork_restpy.testplatform.sessions.ixnetwork.topology.isisspbpseudoifaceattpoint2config import IsisSpbPseudoIfaceAttPoint2Config
		return IsisSpbPseudoIfaceAttPoint2Config(self)

	@property
	def IsisTrillPseudoIfaceAttPoint1Config(self):
		"""An instance of the IsisTrillPseudoIfaceAttPoint1Config class.

		Returns:
			obj(ixnetwork_restpy.testplatform.sessions.ixnetwork.topology.isistrillpseudoifaceattpoint1config.IsisTrillPseudoIfaceAttPoint1Config)

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		from ixnetwork_restpy.testplatform.sessions.ixnetwork.topology.isistrillpseudoifaceattpoint1config import IsisTrillPseudoIfaceAttPoint1Config
		return IsisTrillPseudoIfaceAttPoint1Config(self)

	@property
	def IsisTrillPseudoIfaceAttPoint2Config(self):
		"""An instance of the IsisTrillPseudoIfaceAttPoint2Config class.

		Returns:
			obj(ixnetwork_restpy.testplatform.sessions.ixnetwork.topology.isistrillpseudoifaceattpoint2config.IsisTrillPseudoIfaceAttPoint2Config)

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		from ixnetwork_restpy.testplatform.sessions.ixnetwork.topology.isistrillpseudoifaceattpoint2config import IsisTrillPseudoIfaceAttPoint2Config
		return IsisTrillPseudoIfaceAttPoint2Config(self)

	@property
	def Count(self):
		"""Number of elements inside associated multiplier-scaled container object, e.g. number of devices inside a Device Group

		Returns:
			number
		"""
		return self._get_attribute('count')

	@property
	def DescriptiveName(self):
		"""Longer, more descriptive name for element. It's not guaranteed to be unique like -name-, but maybe offers more context

		Returns:
			str
		"""
		return self._get_attribute('descriptiveName')

	@property
	def LinkType(self):
		"""Link Type

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('linkType')

	@property
	def Name(self):
		"""Name of NGPF element, guaranteed to be unique in Scenario

		Returns:
			str
		"""
		return self._get_attribute('name')
	@Name.setter
	def Name(self, value):
		self._set_attribute('name', value)

	def update(self, Name=None):
		"""Updates a child instance of isisPseudoInterface on the server.

		This method has some named parameters with a type: obj (Multivalue).
		The Multivalue class has the associated documentation that details the possible values for those named parameters.

		Args:
			Name (str): Name of NGPF element, guaranteed to be unique in Scenario

		Raises:
			ServerError: The server has encountered an uncategorized error condition
		"""
		self._update(locals())

	def find(self, Count=None, DescriptiveName=None, Name=None):
		"""Finds and retrieves isisPseudoInterface data from the server.

		All named parameters support regex and can be used to selectively retrieve isisPseudoInterface data from the server.
		By default the find method takes no parameters and will retrieve all isisPseudoInterface data from the server.

		Args:
			Count (number): Number of elements inside associated multiplier-scaled container object, e.g. number of devices inside a Device Group
			DescriptiveName (str): Longer, more descriptive name for element. It's not guaranteed to be unique like -name-, but maybe offers more context
			Name (str): Name of NGPF element, guaranteed to be unique in Scenario

		Returns:
			self: This instance with matching isisPseudoInterface data retrieved from the server available through an iterator or index

		Raises:
			ServerError: The server has encountered an uncategorized error condition
		"""
		return self._select(locals())

	def read(self, href):
		"""Retrieves a single instance of isisPseudoInterface data from the server.

		Args:
			href (str): An href to the instance to be retrieved

		Returns:
			self: This instance with the isisPseudoInterface data from the server available through an iterator or index

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		return self._read(href)

	def get_device_ids(self, PortNames=None, LinkType=None):
		"""Base class infrastructure that gets a list of isisPseudoInterface device ids encapsulated by this object.

		Use the optional regex parameters in the method to refine the list of device ids encapsulated by this object.

		Args:
			PortNames (str): optional regex of port names
			LinkType (str): optional regex of linkType

		Returns:
			list(int): A list of device ids that meets the regex criteria provided in the method parameters

		Raises:
			ServerError: The server has encountered an uncategorized error condition
		"""
		return self._get_ngpf_device_ids(locals())

	def FetchAndUpdateConfigFromCloud(self, *args, **kwargs):
		"""Executes the fetchAndUpdateConfigFromCloud operation on the server.

		fetchAndUpdateConfigFromCloud(Mode:string)
			Args:
				args[0] is Mode (str): 

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = { "Arg1": self.href }
		for i in range(len(args)): payload['Arg%s' % (i + 2)] = args[i]
		for item in kwargs.items(): payload[item[0]] = item[1]
		return self._execute('fetchAndUpdateConfigFromCloud', payload=payload, response_object=None)

	def Start(self):
		"""Executes the start operation on the server.

		Start CPF control plane (equals to promote to negotiated state).

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = { "Arg1": self }
		return self._execute('start', payload=payload, response_object=None)

	def Stop(self):
		"""Executes the stop operation on the server.

		Stop CPF control plane (equals to demote to PreValidated-DoDDone state).

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = { "Arg1": self }
		return self._execute('stop', payload=payload, response_object=None)



# MIT LICENSE
#
# Copyright 1997 - 2019 by IXIA Keysight
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"),
# to deal in the Software without restriction, including without limitation
# the rights to use, copy, modify, merge, publish, distribute, sublicense,
# and/or sell copies of the Software, and to permit persons to whom the
# Software is furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in
# all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
# THE SOFTWARE.
from ixnetwork_restpy.base import Base
from ixnetwork_restpy.files import Files


class LearnedFilter(Base):
	"""The LearnedFilter class encapsulates a required learnedFilter node in the ixnetwork hierarchy.

	An instance of the class can be obtained by accessing the LearnedFilter property from a parent instance.
	The internal properties list will contain one and only one set of properties which is populated when the property is accessed.
	"""

	_SDM_NAME = 'learnedFilter'

	def __init__(self, parent):
		super(LearnedFilter, self).__init__(parent)

	@property
	def AdvRouterId(self):
		"""Filter on the router ID of the router that is originating the LSA.

		Returns:
			str
		"""
		return self._get_attribute('advRouterId')
	@AdvRouterId.setter
	def AdvRouterId(self, value):
		self._set_attribute('advRouterId', value)

	@property
	def AreaSummaryLsaCount(self):
		"""Filter on the number of LSAs in the Summary Area.

		Returns:
			number
		"""
		return self._get_attribute('areaSummaryLsaCount')

	@property
	def EnableAdvRouterId(self):
		"""If true filter on the advertised router ID.

		Returns:
			bool
		"""
		return self._get_attribute('enableAdvRouterId')
	@EnableAdvRouterId.setter
	def EnableAdvRouterId(self, value):
		self._set_attribute('enableAdvRouterId', value)

	@property
	def EnableFilter(self):
		"""Enables the use of the OSPF learned filter.

		Returns:
			bool
		"""
		return self._get_attribute('enableFilter')
	@EnableFilter.setter
	def EnableFilter(self, value):
		self._set_attribute('enableFilter', value)

	@property
	def EnableLinkStateId(self):
		"""If true, filter on the Link State ID.

		Returns:
			bool
		"""
		return self._get_attribute('enableLinkStateId')
	@EnableLinkStateId.setter
	def EnableLinkStateId(self, value):
		self._set_attribute('enableLinkStateId', value)

	@property
	def ExcludeAdvRouterId(self):
		"""If true, filter on no advertised router ID available.

		Returns:
			bool
		"""
		return self._get_attribute('excludeAdvRouterId')
	@ExcludeAdvRouterId.setter
	def ExcludeAdvRouterId(self, value):
		self._set_attribute('excludeAdvRouterId', value)

	@property
	def ExcludeLinkStateId(self):
		"""If true, filter on no Link State ID available.

		Returns:
			bool
		"""
		return self._get_attribute('excludeLinkStateId')
	@ExcludeLinkStateId.setter
	def ExcludeLinkStateId(self, value):
		self._set_attribute('excludeLinkStateId', value)

	@property
	def ExternalLsaCount(self):
		"""Filter on the number of External LSAs.

		Returns:
			number
		"""
		return self._get_attribute('externalLsaCount')

	@property
	def ExternalSummaryLsaCount(self):
		"""Filter on the number of External Summary LSAs.

		Returns:
			number
		"""
		return self._get_attribute('externalSummaryLsaCount')

	@property
	def IsComplete(self):
		"""If true, indicates the Filter operation has finished.

		Returns:
			bool
		"""
		return self._get_attribute('isComplete')

	@property
	def LinkStateId(self):
		"""Filter on the Link State ID.

		Returns:
			str
		"""
		return self._get_attribute('linkStateId')
	@LinkStateId.setter
	def LinkStateId(self, value):
		self._set_attribute('linkStateId', value)

	@property
	def NetworkLsaCount(self):
		"""Filter on the number of Network LSAs.

		Returns:
			number
		"""
		return self._get_attribute('networkLsaCount')

	@property
	def NssaLsaCount(self):
		"""Filter on the number of NSSA LSAs.

		Returns:
			number
		"""
		return self._get_attribute('nssaLsaCount')

	@property
	def OpaqueAreaScopeLsaCount(self):
		"""Filter on the number of Opaque Area LSAs.

		Returns:
			number
		"""
		return self._get_attribute('opaqueAreaScopeLsaCount')

	@property
	def OpaqueAsScopeLsaCount(self):
		"""Filter on the number of AS Scope LSAs.

		Returns:
			number
		"""
		return self._get_attribute('opaqueAsScopeLsaCount')

	@property
	def OpaqueLocalScopeLsaCount(self):
		"""Filter on the number of Local Scope LSAs.

		Returns:
			number
		"""
		return self._get_attribute('opaqueLocalScopeLsaCount')

	@property
	def RouterLsaCount(self):
		"""Filter on the number of Router LSAs.

		Returns:
			number
		"""
		return self._get_attribute('routerLsaCount')

	@property
	def ShowExternalAsLsa(self):
		"""If true, filter on the LSAs from routers with External routes.

		Returns:
			bool
		"""
		return self._get_attribute('showExternalAsLsa')
	@ShowExternalAsLsa.setter
	def ShowExternalAsLsa(self, value):
		self._set_attribute('showExternalAsLsa', value)

	@property
	def ShowNetworkLsa(self):
		"""If true, filter on LSAs from router with Network routes.

		Returns:
			bool
		"""
		return self._get_attribute('showNetworkLsa')
	@ShowNetworkLsa.setter
	def ShowNetworkLsa(self, value):
		self._set_attribute('showNetworkLsa', value)

	@property
	def ShowNssaLsa(self):
		"""If true, filter on LSAs from router with NSSA routes.

		Returns:
			bool
		"""
		return self._get_attribute('showNssaLsa')
	@ShowNssaLsa.setter
	def ShowNssaLsa(self, value):
		self._set_attribute('showNssaLsa', value)

	@property
	def ShowOpaqueAreaLsa(self):
		"""If true, filter on LSAs from router with Opaque Area routes.

		Returns:
			bool
		"""
		return self._get_attribute('showOpaqueAreaLsa')
	@ShowOpaqueAreaLsa.setter
	def ShowOpaqueAreaLsa(self, value):
		self._set_attribute('showOpaqueAreaLsa', value)

	@property
	def ShowOpaqueDomainLsa(self):
		"""If true, filter on LSAs from router with Opaque Domain routes.

		Returns:
			bool
		"""
		return self._get_attribute('showOpaqueDomainLsa')
	@ShowOpaqueDomainLsa.setter
	def ShowOpaqueDomainLsa(self, value):
		self._set_attribute('showOpaqueDomainLsa', value)

	@property
	def ShowOpaqueLocalLsa(self):
		"""If true, filter on LSAs from router with Opaque Local routes.

		Returns:
			bool
		"""
		return self._get_attribute('showOpaqueLocalLsa')
	@ShowOpaqueLocalLsa.setter
	def ShowOpaqueLocalLsa(self, value):
		self._set_attribute('showOpaqueLocalLsa', value)

	@property
	def ShowRouterLsa(self):
		"""If true, filter on LSAs from router with BR or DBR routes.

		Returns:
			bool
		"""
		return self._get_attribute('showRouterLsa')
	@ShowRouterLsa.setter
	def ShowRouterLsa(self, value):
		self._set_attribute('showRouterLsa', value)

	@property
	def ShowSummaryAsLsa(self):
		"""If true, filter on LSAs from router with Summary AS routes.

		Returns:
			bool
		"""
		return self._get_attribute('showSummaryAsLsa')
	@ShowSummaryAsLsa.setter
	def ShowSummaryAsLsa(self, value):
		self._set_attribute('showSummaryAsLsa', value)

	@property
	def ShowSummaryIpLsa(self):
		"""If true, filter on LSAs from router with Summary IP routes.

		Returns:
			bool
		"""
		return self._get_attribute('showSummaryIpLsa')
	@ShowSummaryIpLsa.setter
	def ShowSummaryIpLsa(self, value):
		self._set_attribute('showSummaryIpLsa', value)

	@property
	def TotalLsaCount(self):
		"""Filter on the total number of LSAs.

		Returns:
			number
		"""
		return self._get_attribute('totalLsaCount')

	def update(self, AdvRouterId=None, EnableAdvRouterId=None, EnableFilter=None, EnableLinkStateId=None, ExcludeAdvRouterId=None, ExcludeLinkStateId=None, LinkStateId=None, ShowExternalAsLsa=None, ShowNetworkLsa=None, ShowNssaLsa=None, ShowOpaqueAreaLsa=None, ShowOpaqueDomainLsa=None, ShowOpaqueLocalLsa=None, ShowRouterLsa=None, ShowSummaryAsLsa=None, ShowSummaryIpLsa=None):
		"""Updates a child instance of learnedFilter on the server.

		Args:
			AdvRouterId (str): Filter on the router ID of the router that is originating the LSA.
			EnableAdvRouterId (bool): If true filter on the advertised router ID.
			EnableFilter (bool): Enables the use of the OSPF learned filter.
			EnableLinkStateId (bool): If true, filter on the Link State ID.
			ExcludeAdvRouterId (bool): If true, filter on no advertised router ID available.
			ExcludeLinkStateId (bool): If true, filter on no Link State ID available.
			LinkStateId (str): Filter on the Link State ID.
			ShowExternalAsLsa (bool): If true, filter on the LSAs from routers with External routes.
			ShowNetworkLsa (bool): If true, filter on LSAs from router with Network routes.
			ShowNssaLsa (bool): If true, filter on LSAs from router with NSSA routes.
			ShowOpaqueAreaLsa (bool): If true, filter on LSAs from router with Opaque Area routes.
			ShowOpaqueDomainLsa (bool): If true, filter on LSAs from router with Opaque Domain routes.
			ShowOpaqueLocalLsa (bool): If true, filter on LSAs from router with Opaque Local routes.
			ShowRouterLsa (bool): If true, filter on LSAs from router with BR or DBR routes.
			ShowSummaryAsLsa (bool): If true, filter on LSAs from router with Summary AS routes.
			ShowSummaryIpLsa (bool): If true, filter on LSAs from router with Summary IP routes.

		Raises:
			ServerError: The server has encountered an uncategorized error condition
		"""
		self._update(locals())



# MIT LICENSE
#
# Copyright 1997 - 2019 by IXIA Keysight
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"),
# to deal in the Software without restriction, including without limitation
# the rights to use, copy, modify, merge, publish, distribute, sublicense,
# and/or sell copies of the Software, and to permit persons to whom the
# Software is furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in
# all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
# THE SOFTWARE.
from ixnetwork_restpy.base import Base
from ixnetwork_restpy.files import Files


class BgpIpv6Peer(Base):
	"""The BgpIpv6Peer class encapsulates a required bgpIpv6Peer node in the ixnetwork hierarchy.

	An instance of the class can be obtained by accessing the BgpIpv6Peer property from a parent instance.
	The internal properties list will contain one and only one set of properties which is populated when the property is accessed.
	"""

	_SDM_NAME = 'bgpIpv6Peer'

	def __init__(self, parent):
		super(BgpIpv6Peer, self).__init__(parent)

	@property
	def StartRate(self):
		"""An instance of the StartRate class.

		Returns:
			obj(ixnetwork_restpy.testplatform.sessions.ixnetwork.globals.topology.bgpipv6peer.startrate.startrate.StartRate)

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		from ixnetwork_restpy.testplatform.sessions.ixnetwork.globals.topology.bgpipv6peer.startrate.startrate import StartRate
		return StartRate(self)._select()

	@property
	def StopRate(self):
		"""An instance of the StopRate class.

		Returns:
			obj(ixnetwork_restpy.testplatform.sessions.ixnetwork.globals.topology.bgpipv6peer.stoprate.stoprate.StopRate)

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		from ixnetwork_restpy.testplatform.sessions.ixnetwork.globals.topology.bgpipv6peer.stoprate.stoprate import StopRate
		return StopRate(self)._select()

	@property
	def TlvEditor(self):
		"""An instance of the TlvEditor class.

		Returns:
			obj(ixnetwork_restpy.testplatform.sessions.ixnetwork.globals.topology.tlveditor.tlveditor.TlvEditor)

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		from ixnetwork_restpy.testplatform.sessions.ixnetwork.globals.topology.tlveditor.tlveditor import TlvEditor
		return TlvEditor(self)

	@property
	def BIERTunnelType(self):
		"""BIER Tunnel Type

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('BIERTunnelType')

	@property
	def LLGRCapabilityCode(self):
		"""Long Live Graceful Restart Capability Code

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('LLGRCapabilityCode')

	@property
	def BgpConfMemType(self):
		"""BGP Confederation Member Type

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('bgpConfMemType')

	@property
	def BgpRouterId(self):
		"""BGP Router-ID Type

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('bgpRouterId')

	@property
	def BindingType(self):
		"""Binding Sub-TLV Type

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('bindingType')

	@property
	def ColorType(self):
		"""Color Sub-TLV Type

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('colorType')

	@property
	def Count(self):
		"""Number of elements inside associated multiplier-scaled container object, e.g. number of devices inside a Device Group

		Returns:
			number
		"""
		return self._get_attribute('count')

	@property
	def DescriptiveName(self):
		"""Longer, more descriptive name for element. It's not guaranteed to be unique like -name-, but maybe offers more context

		Returns:
			str
		"""
		return self._get_attribute('descriptiveName')

	@property
	def DisableReceivedUpdateValidation(self):
		"""Disable Received Update Validation (Enabled for High Performance)

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('disableReceivedUpdateValidation')

	@property
	def EnLenthForPolicyNLRI(self):
		"""Include Length Field in SR TE Policy NLRI

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('enLenthForPolicyNLRI')

	@property
	def EnableAdVplsPrefixLength(self):
		"""Enable AD VPLS Prefix Length in Bits

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('enableAdVplsPrefixLength')

	@property
	def IBgpTester4BytesAsNumber(self):
		"""Tester 4 Byte AS# for iBGP

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('iBgpTester4BytesAsNumber')

	@property
	def IBgpTesterAsNumber(self):
		"""Tester AS# for iBGP

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('iBgpTesterAsNumber')

	@property
	def InitiateEbgpActiveConnection(self):
		"""Initiate eBGP Active Connection

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('initiateEbgpActiveConnection')

	@property
	def InitiateIbgpActiveConnection(self):
		"""Initiate iBGP Active Connection

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('initiateIbgpActiveConnection')

	@property
	def Ipv4AddrIndexType(self):
		"""IPv4 Address + Index Type

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('ipv4AddrIndexType')

	@property
	def Ipv4LocRemoteAddrType(self):
		"""IPv4 Local and Remote Address

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('ipv4LocRemoteAddrType')

	@property
	def Ipv4NodeAddrType(self):
		"""IPv4 Node Address Type

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('ipv4NodeAddrType')

	@property
	def Ipv6AddrIndexType(self):
		"""IPv6 Address + Index Type

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('ipv6AddrIndexType')

	@property
	def Ipv6LocRemoteAddrType(self):
		"""IPv6 Local and Remote Address

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('ipv6LocRemoteAddrType')

	@property
	def Ipv6NodeAddrType(self):
		"""IPv6 Node Address Type

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('ipv6NodeAddrType')

	@property
	def Ipv6SIDType(self):
		"""IPv6 SID Type

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('ipv6SIDType')

	@property
	def LenthForPolicyNLRI(self):
		"""Length Unit

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('lenthForPolicyNLRI')

	@property
	def MldpP2mpFecType(self):
		"""MLDP P2MP FEC Type (Hex)

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('mldpP2mpFecType')

	@property
	def MplsSIDType(self):
		"""MPLS SID Type

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('mplsSIDType')

	@property
	def Name(self):
		"""Name of NGPF element, guaranteed to be unique in Scenario

		Returns:
			str
		"""
		return self._get_attribute('name')
	@Name.setter
	def Name(self, value):
		self._set_attribute('name', value)

	@property
	def PeerAdjSidType(self):
		"""Peer-Adj-SID Type

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('peerAdjSidType')

	@property
	def PeerNodeSidType(self):
		"""Peer-Node-SID Type

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('peerNodeSidType')

	@property
	def PeerSetSidType(self):
		"""Peer-Set-SID Type

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('peerSetSidType')

	@property
	def PreferenceType(self):
		"""Preference Sub-TLV Type

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('preferenceType')

	@property
	def PrefixSIDAttrType(self):
		"""Prefix SID Attr Type

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('prefixSIDAttrType')

	@property
	def ProtoclIdType(self):
		"""Protocol-ID Type

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('protoclIdType')

	@property
	def RemoteEndpointType(self):
		"""Remote Endpoint Sub-TLV Type

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('remoteEndpointType')

	@property
	def RequestVpnLabelExchangeOverLsp(self):
		"""Request VPN Label Exchange over LSP

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('requestVpnLabelExchangeOverLsp')

	@property
	def RowNames(self):
		"""Name of rows

		Returns:
			list(str)
		"""
		return self._get_attribute('rowNames')

	@property
	def SRv6VPNSIDTLVType(self):
		"""SRv6-VPN SID TLV Type

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('sRv6VPNSIDTLVType')

	@property
	def SegmentListType(self):
		"""Segment List Sub-TLV Type

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('segmentListType')

	@property
	def SrtePolicyAttrType(self):
		"""Tunnel Encaps Attribute Type

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('srtePolicyAttrType')

	@property
	def SrtePolicySAFI(self):
		"""SR TE Policy SAFI

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('srtePolicySAFI')

	@property
	def SrtePolicyType(self):
		"""Tunnel Type for SR Policy

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('srtePolicyType')

	@property
	def Srv6DraftNum(self):
		"""L3VPN SRv6 Draft Version Number

		Returns:
			str(version03|version04)
		"""
		return self._get_attribute('srv6DraftNum')
	@Srv6DraftNum.setter
	def Srv6DraftNum(self, value):
		self._set_attribute('srv6DraftNum', value)

	@property
	def TriggerVplsPwInitiation(self):
		"""Trigger VPLS PW Initiation

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('triggerVplsPwInitiation')

	@property
	def UdpDestinationPort(self):
		"""UDP Destination Port for VXLAN

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('udpDestinationPort')

	@property
	def UseUnicastDestMacForBierTraffic(self):
		"""Use Unicast Dst MAC for Traffic

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('useUnicastDestMacForBierTraffic')

	@property
	def VPNSIDType(self):
		"""L3VPN SID Type

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('vPNSIDType')

	@property
	def VrfRouteImportExtendedCommunitySubType(self):
		"""VRF Route Import Extended Community Sub Type

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('vrfRouteImportExtendedCommunitySubType')

	@property
	def WeightType(self):
		"""Weight Sub-TLV Type

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('weightType')

	def update(self, Name=None, Srv6DraftNum=None):
		"""Updates a child instance of bgpIpv6Peer on the server.

		This method has some named parameters with a type: obj (Multivalue).
		The Multivalue class has the associated documentation that details the possible values for those named parameters.

		Args:
			Name (str): Name of NGPF element, guaranteed to be unique in Scenario
			Srv6DraftNum (str(version03|version04)): L3VPN SRv6 Draft Version Number

		Raises:
			ServerError: The server has encountered an uncategorized error condition
		"""
		self._update(locals())

	def get_device_ids(self, PortNames=None, BIERTunnelType=None, LLGRCapabilityCode=None, BgpConfMemType=None, BgpRouterId=None, BindingType=None, ColorType=None, DisableReceivedUpdateValidation=None, EnLenthForPolicyNLRI=None, EnableAdVplsPrefixLength=None, IBgpTester4BytesAsNumber=None, IBgpTesterAsNumber=None, InitiateEbgpActiveConnection=None, InitiateIbgpActiveConnection=None, Ipv4AddrIndexType=None, Ipv4LocRemoteAddrType=None, Ipv4NodeAddrType=None, Ipv6AddrIndexType=None, Ipv6LocRemoteAddrType=None, Ipv6NodeAddrType=None, Ipv6SIDType=None, LenthForPolicyNLRI=None, MldpP2mpFecType=None, MplsSIDType=None, PeerAdjSidType=None, PeerNodeSidType=None, PeerSetSidType=None, PreferenceType=None, PrefixSIDAttrType=None, ProtoclIdType=None, RemoteEndpointType=None, RequestVpnLabelExchangeOverLsp=None, SRv6VPNSIDTLVType=None, SegmentListType=None, SrtePolicyAttrType=None, SrtePolicySAFI=None, SrtePolicyType=None, TriggerVplsPwInitiation=None, UdpDestinationPort=None, UseUnicastDestMacForBierTraffic=None, VPNSIDType=None, VrfRouteImportExtendedCommunitySubType=None, WeightType=None):
		"""Base class infrastructure that gets a list of bgpIpv6Peer device ids encapsulated by this object.

		Use the optional regex parameters in the method to refine the list of device ids encapsulated by this object.

		Args:
			PortNames (str): optional regex of port names
			BIERTunnelType (str): optional regex of BIERTunnelType
			LLGRCapabilityCode (str): optional regex of LLGRCapabilityCode
			BgpConfMemType (str): optional regex of bgpConfMemType
			BgpRouterId (str): optional regex of bgpRouterId
			BindingType (str): optional regex of bindingType
			ColorType (str): optional regex of colorType
			DisableReceivedUpdateValidation (str): optional regex of disableReceivedUpdateValidation
			EnLenthForPolicyNLRI (str): optional regex of enLenthForPolicyNLRI
			EnableAdVplsPrefixLength (str): optional regex of enableAdVplsPrefixLength
			IBgpTester4BytesAsNumber (str): optional regex of iBgpTester4BytesAsNumber
			IBgpTesterAsNumber (str): optional regex of iBgpTesterAsNumber
			InitiateEbgpActiveConnection (str): optional regex of initiateEbgpActiveConnection
			InitiateIbgpActiveConnection (str): optional regex of initiateIbgpActiveConnection
			Ipv4AddrIndexType (str): optional regex of ipv4AddrIndexType
			Ipv4LocRemoteAddrType (str): optional regex of ipv4LocRemoteAddrType
			Ipv4NodeAddrType (str): optional regex of ipv4NodeAddrType
			Ipv6AddrIndexType (str): optional regex of ipv6AddrIndexType
			Ipv6LocRemoteAddrType (str): optional regex of ipv6LocRemoteAddrType
			Ipv6NodeAddrType (str): optional regex of ipv6NodeAddrType
			Ipv6SIDType (str): optional regex of ipv6SIDType
			LenthForPolicyNLRI (str): optional regex of lenthForPolicyNLRI
			MldpP2mpFecType (str): optional regex of mldpP2mpFecType
			MplsSIDType (str): optional regex of mplsSIDType
			PeerAdjSidType (str): optional regex of peerAdjSidType
			PeerNodeSidType (str): optional regex of peerNodeSidType
			PeerSetSidType (str): optional regex of peerSetSidType
			PreferenceType (str): optional regex of preferenceType
			PrefixSIDAttrType (str): optional regex of prefixSIDAttrType
			ProtoclIdType (str): optional regex of protoclIdType
			RemoteEndpointType (str): optional regex of remoteEndpointType
			RequestVpnLabelExchangeOverLsp (str): optional regex of requestVpnLabelExchangeOverLsp
			SRv6VPNSIDTLVType (str): optional regex of sRv6VPNSIDTLVType
			SegmentListType (str): optional regex of segmentListType
			SrtePolicyAttrType (str): optional regex of srtePolicyAttrType
			SrtePolicySAFI (str): optional regex of srtePolicySAFI
			SrtePolicyType (str): optional regex of srtePolicyType
			TriggerVplsPwInitiation (str): optional regex of triggerVplsPwInitiation
			UdpDestinationPort (str): optional regex of udpDestinationPort
			UseUnicastDestMacForBierTraffic (str): optional regex of useUnicastDestMacForBierTraffic
			VPNSIDType (str): optional regex of vPNSIDType
			VrfRouteImportExtendedCommunitySubType (str): optional regex of vrfRouteImportExtendedCommunitySubType
			WeightType (str): optional regex of weightType

		Returns:
			list(int): A list of device ids that meets the regex criteria provided in the method parameters

		Raises:
			ServerError: The server has encountered an uncategorized error condition
		"""
		return self._get_ngpf_device_ids(locals())

	def FetchAndUpdateConfigFromCloud(self, *args, **kwargs):
		"""Executes the fetchAndUpdateConfigFromCloud operation on the server.

		fetchAndUpdateConfigFromCloud(Mode:string)
			Args:
				args[0] is Mode (str): 

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = { "Arg1": self.href }
		for i in range(len(args)): payload['Arg%s' % (i + 2)] = args[i]
		for item in kwargs.items(): payload[item[0]] = item[1]
		return self._execute('fetchAndUpdateConfigFromCloud', payload=payload, response_object=None)



# MIT LICENSE
#
# Copyright 1997 - 2019 by IXIA Keysight
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"),
# to deal in the Software without restriction, including without limitation
# the rights to use, copy, modify, merge, publish, distribute, sublicense,
# and/or sell copies of the Software, and to permit persons to whom the
# Software is furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in
# all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
# THE SOFTWARE.
from ixnetwork_restpy.base import Base
from ixnetwork_restpy.files import Files


class FeaturesSupported(Base):
	"""The FeaturesSupported class encapsulates a required featuresSupported node in the ixnetwork hierarchy.

	An instance of the class can be obtained by accessing the FeaturesSupported property from a parent instance.
	The internal properties list will contain one and only one set of properties which is populated when the property is accessed.
	"""

	_SDM_NAME = 'featuresSupported'

	def __init__(self, parent):
		super(FeaturesSupported, self).__init__(parent)

	@property
	def ApplyActions(self):
		"""Select the type of apply action instructions that the table flow entry will support. The selected actions associated with a flow are applied immediately.

		Returns:
			bool
		"""
		return self._get_attribute('applyActions')
	@ApplyActions.setter
	def ApplyActions(self, value):
		self._set_attribute('applyActions', value)

	@property
	def ApplyActionsMiss(self):
		"""Select the type of apply action miss instructions that the table miss flow entry will support.

		Returns:
			bool
		"""
		return self._get_attribute('applyActionsMiss')
	@ApplyActionsMiss.setter
	def ApplyActionsMiss(self, value):
		self._set_attribute('applyActionsMiss', value)

	@property
	def ApplySetField(self):
		"""Apply set field property.

		Returns:
			bool
		"""
		return self._get_attribute('applySetField')
	@ApplySetField.setter
	def ApplySetField(self, value):
		self._set_attribute('applySetField', value)

	@property
	def ApplySetFieldMiss(self):
		"""Apply set field for table-miss.

		Returns:
			bool
		"""
		return self._get_attribute('applySetFieldMiss')
	@ApplySetFieldMiss.setter
	def ApplySetFieldMiss(self, value):
		self._set_attribute('applySetFieldMiss', value)

	@property
	def Experimenter(self):
		"""This view lists all the experimenter properties that can be configured. Experimenter messages provide a standard way for OpenFlow switches to offer additional functionality within the OpenFlow message type space.

		Returns:
			bool
		"""
		return self._get_attribute('experimenter')
	@Experimenter.setter
	def Experimenter(self, value):
		self._set_attribute('experimenter', value)

	@property
	def ExperimenterMiss(self):
		"""Experimenter for table-miss.

		Returns:
			bool
		"""
		return self._get_attribute('experimenterMiss')
	@ExperimenterMiss.setter
	def ExperimenterMiss(self, value):
		self._set_attribute('experimenterMiss', value)

	@property
	def Instruction(self):
		"""It select the type of instructions that the table flow entry will support

		Returns:
			bool
		"""
		return self._get_attribute('instruction')
	@Instruction.setter
	def Instruction(self, value):
		self._set_attribute('instruction', value)

	@property
	def InstructionMiss(self):
		"""Select the type of instruction miss capabilities that the table miss flow entry will support.

		Returns:
			bool
		"""
		return self._get_attribute('instructionMiss')
	@InstructionMiss.setter
	def InstructionMiss(self, value):
		self._set_attribute('instructionMiss', value)

	@property
	def Match(self):
		"""Select the type of match instructions that the table will support.

		Returns:
			bool
		"""
		return self._get_attribute('match')
	@Match.setter
	def Match(self, value):
		self._set_attribute('match', value)

	@property
	def NextTable(self):
		"""Specify the array of tables that can be directly reached from the present table using the GoTo Table instruction.

		Returns:
			bool
		"""
		return self._get_attribute('nextTable')
	@NextTable.setter
	def NextTable(self, value):
		self._set_attribute('nextTable', value)

	@property
	def NextTableMiss(self):
		"""Specify the Next table Miss value.

		Returns:
			bool
		"""
		return self._get_attribute('nextTableMiss')
	@NextTableMiss.setter
	def NextTableMiss(self, value):
		self._set_attribute('nextTableMiss', value)

	@property
	def Wildcards(self):
		"""Select the type of wildcard instructions that the table will support.

		Returns:
			bool
		"""
		return self._get_attribute('wildcards')
	@Wildcards.setter
	def Wildcards(self, value):
		self._set_attribute('wildcards', value)

	@property
	def WriteActions(self):
		"""Select the type of write action instructions that the table flow entry will support.

		Returns:
			bool
		"""
		return self._get_attribute('writeActions')
	@WriteActions.setter
	def WriteActions(self, value):
		self._set_attribute('writeActions', value)

	@property
	def WriteActionsMiss(self):
		"""Select the type of write action miss instructions that the table miss flow entry will support.

		Returns:
			bool
		"""
		return self._get_attribute('writeActionsMiss')
	@WriteActionsMiss.setter
	def WriteActionsMiss(self, value):
		self._set_attribute('writeActionsMiss', value)

	@property
	def WriteSetField(self):
		"""Apply set field for table-miss.

		Returns:
			bool
		"""
		return self._get_attribute('writeSetField')
	@WriteSetField.setter
	def WriteSetField(self, value):
		self._set_attribute('writeSetField', value)

	@property
	def WriteSetFieldMiss(self):
		"""Write set field for table-miss.

		Returns:
			bool
		"""
		return self._get_attribute('writeSetFieldMiss')
	@WriteSetFieldMiss.setter
	def WriteSetFieldMiss(self, value):
		self._set_attribute('writeSetFieldMiss', value)

	def update(self, ApplyActions=None, ApplyActionsMiss=None, ApplySetField=None, ApplySetFieldMiss=None, Experimenter=None, ExperimenterMiss=None, Instruction=None, InstructionMiss=None, Match=None, NextTable=None, NextTableMiss=None, Wildcards=None, WriteActions=None, WriteActionsMiss=None, WriteSetField=None, WriteSetFieldMiss=None):
		"""Updates a child instance of featuresSupported on the server.

		Args:
			ApplyActions (bool): Select the type of apply action instructions that the table flow entry will support. The selected actions associated with a flow are applied immediately.
			ApplyActionsMiss (bool): Select the type of apply action miss instructions that the table miss flow entry will support.
			ApplySetField (bool): Apply set field property.
			ApplySetFieldMiss (bool): Apply set field for table-miss.
			Experimenter (bool): This view lists all the experimenter properties that can be configured. Experimenter messages provide a standard way for OpenFlow switches to offer additional functionality within the OpenFlow message type space.
			ExperimenterMiss (bool): Experimenter for table-miss.
			Instruction (bool): It select the type of instructions that the table flow entry will support
			InstructionMiss (bool): Select the type of instruction miss capabilities that the table miss flow entry will support.
			Match (bool): Select the type of match instructions that the table will support.
			NextTable (bool): Specify the array of tables that can be directly reached from the present table using the GoTo Table instruction.
			NextTableMiss (bool): Specify the Next table Miss value.
			Wildcards (bool): Select the type of wildcard instructions that the table will support.
			WriteActions (bool): Select the type of write action instructions that the table flow entry will support.
			WriteActionsMiss (bool): Select the type of write action miss instructions that the table miss flow entry will support.
			WriteSetField (bool): Apply set field for table-miss.
			WriteSetFieldMiss (bool): Write set field for table-miss.

		Raises:
			ServerError: The server has encountered an uncategorized error condition
		"""
		self._update(locals())



# MIT LICENSE
#
# Copyright 1997 - 2019 by IXIA Keysight
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"),
# to deal in the Software without restriction, including without limitation
# the rights to use, copy, modify, merge, publish, distribute, sublicense,
# and/or sell copies of the Software, and to permit persons to whom the
# Software is furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in
# all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
# THE SOFTWARE.
from ixnetwork_restpy.base import Base
from ixnetwork_restpy.files import Files


class DynamicRate(Base):
	"""The DynamicRate class encapsulates a system managed dynamicRate node in the ixnetwork hierarchy.

	An instance of the class can be obtained by accessing the DynamicRate property from a parent instance.
	The internal properties list will be empty when the property is accessed and is populated from the server by using the find method.
	"""

	_SDM_NAME = 'dynamicRate'

	def __init__(self, parent):
		super(DynamicRate, self).__init__(parent)

	@property
	def BitRateUnitsType(self):
		"""The rate units for transmitting packet.

		Returns:
			str(bitsPerSec|bytesPerSec|kbitsPerSec|kbytesPerSec|mbitsPerSec|mbytesPerSec)
		"""
		return self._get_attribute('bitRateUnitsType')
	@BitRateUnitsType.setter
	def BitRateUnitsType(self, value):
		self._set_attribute('bitRateUnitsType', value)

	@property
	def EnforceMinimumInterPacketGap(self):
		"""Sets the minimum inter-packet gap allowed for Ethernet ports only.

		Returns:
			number
		"""
		return self._get_attribute('enforceMinimumInterPacketGap')
	@EnforceMinimumInterPacketGap.setter
	def EnforceMinimumInterPacketGap(self, value):
		self._set_attribute('enforceMinimumInterPacketGap', value)

	@property
	def HighLevelStreamName(self):
		"""The name of the high level stream

		Returns:
			str
		"""
		return self._get_attribute('highLevelStreamName')

	@property
	def InterPacketGapUnitsType(self):
		"""The inter-packet gap expressed in units.

		Returns:
			str(bytes|nanoseconds)
		"""
		return self._get_attribute('interPacketGapUnitsType')
	@InterPacketGapUnitsType.setter
	def InterPacketGapUnitsType(self, value):
		self._set_attribute('interPacketGapUnitsType', value)

	@property
	def OverSubscribed(self):
		"""If true, the packet transmission rate is oversubscribed.

		Returns:
			bool
		"""
		return self._get_attribute('overSubscribed')

	@property
	def Rate(self):
		"""The rate at which packet is transmitted.

		Returns:
			number
		"""
		return self._get_attribute('rate')
	@Rate.setter
	def Rate(self, value):
		self._set_attribute('rate', value)

	@property
	def RateType(self):
		"""The types of packet rate transmission.

		Returns:
			str(bitsPerSecond|framesPerSecond|interPacketGap|percentLineRate)
		"""
		return self._get_attribute('rateType')
	@RateType.setter
	def RateType(self, value):
		self._set_attribute('rateType', value)

	@property
	def TrafficItemName(self):
		"""The name of the parent traffic item.

		Returns:
			str
		"""
		return self._get_attribute('trafficItemName')

	@property
	def TxPort(self):
		"""The transmitting port.

		Returns:
			number
		"""
		return self._get_attribute('txPort')

	def update(self, BitRateUnitsType=None, EnforceMinimumInterPacketGap=None, InterPacketGapUnitsType=None, Rate=None, RateType=None):
		"""Updates a child instance of dynamicRate on the server.

		Args:
			BitRateUnitsType (str(bitsPerSec|bytesPerSec|kbitsPerSec|kbytesPerSec|mbitsPerSec|mbytesPerSec)): The rate units for transmitting packet.
			EnforceMinimumInterPacketGap (number): Sets the minimum inter-packet gap allowed for Ethernet ports only.
			InterPacketGapUnitsType (str(bytes|nanoseconds)): The inter-packet gap expressed in units.
			Rate (number): The rate at which packet is transmitted.
			RateType (str(bitsPerSecond|framesPerSecond|interPacketGap|percentLineRate)): The types of packet rate transmission.

		Raises:
			ServerError: The server has encountered an uncategorized error condition
		"""
		self._update(locals())

	def find(self, BitRateUnitsType=None, EnforceMinimumInterPacketGap=None, HighLevelStreamName=None, InterPacketGapUnitsType=None, OverSubscribed=None, Rate=None, RateType=None, TrafficItemName=None, TxPort=None):
		"""Finds and retrieves dynamicRate data from the server.

		All named parameters support regex and can be used to selectively retrieve dynamicRate data from the server.
		By default the find method takes no parameters and will retrieve all dynamicRate data from the server.

		Args:
			BitRateUnitsType (str(bitsPerSec|bytesPerSec|kbitsPerSec|kbytesPerSec|mbitsPerSec|mbytesPerSec)): The rate units for transmitting packet.
			EnforceMinimumInterPacketGap (number): Sets the minimum inter-packet gap allowed for Ethernet ports only.
			HighLevelStreamName (str): The name of the high level stream
			InterPacketGapUnitsType (str(bytes|nanoseconds)): The inter-packet gap expressed in units.
			OverSubscribed (bool): If true, the packet transmission rate is oversubscribed.
			Rate (number): The rate at which packet is transmitted.
			RateType (str(bitsPerSecond|framesPerSecond|interPacketGap|percentLineRate)): The types of packet rate transmission.
			TrafficItemName (str): The name of the parent traffic item.
			TxPort (number): The transmitting port.

		Returns:
			self: This instance with matching dynamicRate data retrieved from the server available through an iterator or index

		Raises:
			ServerError: The server has encountered an uncategorized error condition
		"""
		return self._select(locals())

	def read(self, href):
		"""Retrieves a single instance of dynamicRate data from the server.

		Args:
			href (str): An href to the instance to be retrieved

		Returns:
			self: This instance with the dynamicRate data from the server available through an iterator or index

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		return self._read(href)



# MIT LICENSE
#
# Copyright 1997 - 2019 by IXIA Keysight
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"),
# to deal in the Software without restriction, including without limitation
# the rights to use, copy, modify, merge, publish, distribute, sublicense,
# and/or sell copies of the Software, and to permit persons to whom the
# Software is furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in
# all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
# THE SOFTWARE.
from ixnetwork_restpy.base import Base
from ixnetwork_restpy.files import Files


class PacketInHeaders(Base):
	"""The PacketInHeaders class encapsulates a required packetInHeaders node in the ixnetwork hierarchy.

	An instance of the class can be obtained by accessing the PacketInHeaders property from a parent instance.
	The internal properties list will contain one and only one set of properties which is populated when the property is accessed.
	"""

	_SDM_NAME = 'packetInHeaders'

	def __init__(self, parent):
		super(PacketInHeaders, self).__init__(parent)

	@property
	def EthernetDestinationAddress(self):
		"""Indicates the Ethernet destination address for the packet.

		Returns:
			str
		"""
		return self._get_attribute('ethernetDestinationAddress')

	@property
	def EthernetSourceAddress(self):
		"""Indicates the ethernet address of the source from which this packet arrived.

		Returns:
			str
		"""
		return self._get_attribute('ethernetSourceAddress')

	@property
	def EthernetType(self):
		"""Indicates the ethernet frame type.

		Returns:
			str
		"""
		return self._get_attribute('ethernetType')

	@property
	def Ipv4DestinationAddress(self):
		"""Indicates the IPv4 destination address for this packet.

		Returns:
			str
		"""
		return self._get_attribute('ipv4DestinationAddress')

	@property
	def Ipv4Protocol(self):
		"""Defines the protocol used in the data portion of the IP datagram.

		Returns:
			str
		"""
		return self._get_attribute('ipv4Protocol')

	@property
	def Ipv4SourceAddress(self):
		"""Indicates the IPv4 address of the source from which this packet arrived.

		Returns:
			str
		"""
		return self._get_attribute('ipv4SourceAddress')

	@property
	def Ipv6DestinationAddress(self):
		"""Indicates the IPv6 destination address for this packet.

		Returns:
			str
		"""
		return self._get_attribute('ipv6DestinationAddress')

	@property
	def Ipv6FlowLabel(self):
		"""Originally created for giving real-time applications special service.The flow label when set to a non-zero value now serves as a hint to routers and switches with multiple outbound paths that these packets should stay on the same path so that they will not be re-ordered.

		Returns:
			str
		"""
		return self._get_attribute('ipv6FlowLabel')

	@property
	def Ipv6SourceAddress(self):
		"""Indicates the IPv6 address of the source from which this packet arrived.

		Returns:
			str
		"""
		return self._get_attribute('ipv6SourceAddress')

	@property
	def TcpDestinationPort(self):
		"""Identifies the TCP port number of the destination application program.

		Returns:
			str
		"""
		return self._get_attribute('tcpDestinationPort')

	@property
	def TcpSourcePort(self):
		"""Identifies the TCP port number of the source application program.

		Returns:
			str
		"""
		return self._get_attribute('tcpSourcePort')

	@property
	def UdpDestinationPort(self):
		"""Identifies the UDP port number of the destination application program.

		Returns:
			str
		"""
		return self._get_attribute('udpDestinationPort')

	@property
	def UdpSourcePort(self):
		"""Identifies the UDP port number of the source application program.

		Returns:
			str
		"""
		return self._get_attribute('udpSourcePort')

	@property
	def UniquePacketCount(self):
		"""Indicates the packet-in count in this Range.

		Returns:
			str
		"""
		return self._get_attribute('uniquePacketCount')

	@property
	def VlanId(self):
		"""Indicates the field specifying the VLAN to which the frame belongs.

		Returns:
			str
		"""
		return self._get_attribute('vlanId')

	@property
	def VlanPriority(self):
		"""Indicates the frame priority level.

		Returns:
			str
		"""
		return self._get_attribute('vlanPriority')



# MIT LICENSE
#
# Copyright 1997 - 2019 by IXIA Keysight
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"),
# to deal in the Software without restriction, including without limitation
# the rights to use, copy, modify, merge, publish, distribute, sublicense,
# and/or sell copies of the Software, and to permit persons to whom the
# Software is furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in
# all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
# THE SOFTWARE.
from ixnetwork_restpy.base import Base
from ixnetwork_restpy.files import Files


class PingLearnedInfo(Base):
	"""The PingLearnedInfo class encapsulates a system managed pingLearnedInfo node in the ixnetwork hierarchy.

	An instance of the class can be obtained by accessing the PingLearnedInfo property from a parent instance.
	The internal properties list will be empty when the property is accessed and is populated from the server by using the find method.
	"""

	_SDM_NAME = 'pingLearnedInfo'

	def __init__(self, parent):
		super(PingLearnedInfo, self).__init__(parent)

	@property
	def ErrorTlvType(self):
		"""This signifies Error TLV if it is received in lsp ping echo reply message.

		Returns:
			number
		"""
		return self._get_attribute('errorTlvType')

	@property
	def IncomingLabelOuterInner(self):
		"""This signifies the incoming label information.

		Returns:
			str
		"""
		return self._get_attribute('incomingLabelOuterInner')

	@property
	def InterfaceLabelStackTlvInterface(self):
		"""This Signifies the inclusion of the Interface Id within Interface and Label Stack TLV in received lsp ping echo reply message.

		Returns:
			number
		"""
		return self._get_attribute('interfaceLabelStackTlvInterface')

	@property
	def InterfaceLabelStackTlvIpAddress(self):
		"""This Signifies the inclusion of the IP Address within Interface and Label Stack TLV in received lsp ping echo reply message.

		Returns:
			str
		"""
		return self._get_attribute('interfaceLabelStackTlvIpAddress')

	@property
	def InterfaceLabelStackTlvLabels(self):
		"""This signifies the label stack in Interface and Label Stack TLV received in lsp ping echo reply message.

		Returns:
			str
		"""
		return self._get_attribute('interfaceLabelStackTlvLabels')

	@property
	def OutgoingLabelOuterInner(self):
		"""This signifies the Outgoing Label information.

		Returns:
			str
		"""
		return self._get_attribute('outgoingLabelOuterInner')

	@property
	def Reachability(self):
		"""This specifies whether the queried MEP could be reached or not, Yes or No.

		Returns:
			bool
		"""
		return self._get_attribute('reachability')

	@property
	def ReturnCode(self):
		"""This signifies the value of the return code in the Echo reply message.

		Returns:
			str
		"""
		return self._get_attribute('returnCode')

	@property
	def ReturnSubcode(self):
		"""This signifies the value of the return sub-code in the Echo reply message.

		Returns:
			number
		"""
		return self._get_attribute('returnSubcode')

	@property
	def ReversePathVerificationCode(self):
		"""This Signifies the reverse path verification code received in the lsp ping echo reply message.

		Returns:
			str
		"""
		return self._get_attribute('reversePathVerificationCode')

	@property
	def Rtt(self):
		"""This signifies the Round Trip Time.

		Returns:
			str
		"""
		return self._get_attribute('rtt')

	@property
	def SenderHandle(self):
		"""This signifies the sender handle information.

		Returns:
			number
		"""
		return self._get_attribute('senderHandle')

	@property
	def SequenceNumber(self):
		"""This signifies the sequence number for the ping learned information.

		Returns:
			number
		"""
		return self._get_attribute('sequenceNumber')

	@property
	def Type(self):
		"""This signifies the type of the learned info.

		Returns:
			str
		"""
		return self._get_attribute('type')

	def find(self, ErrorTlvType=None, IncomingLabelOuterInner=None, InterfaceLabelStackTlvInterface=None, InterfaceLabelStackTlvIpAddress=None, InterfaceLabelStackTlvLabels=None, OutgoingLabelOuterInner=None, Reachability=None, ReturnCode=None, ReturnSubcode=None, ReversePathVerificationCode=None, Rtt=None, SenderHandle=None, SequenceNumber=None, Type=None):
		"""Finds and retrieves pingLearnedInfo data from the server.

		All named parameters support regex and can be used to selectively retrieve pingLearnedInfo data from the server.
		By default the find method takes no parameters and will retrieve all pingLearnedInfo data from the server.

		Args:
			ErrorTlvType (number): This signifies Error TLV if it is received in lsp ping echo reply message.
			IncomingLabelOuterInner (str): This signifies the incoming label information.
			InterfaceLabelStackTlvInterface (number): This Signifies the inclusion of the Interface Id within Interface and Label Stack TLV in received lsp ping echo reply message.
			InterfaceLabelStackTlvIpAddress (str): This Signifies the inclusion of the IP Address within Interface and Label Stack TLV in received lsp ping echo reply message.
			InterfaceLabelStackTlvLabels (str): This signifies the label stack in Interface and Label Stack TLV received in lsp ping echo reply message.
			OutgoingLabelOuterInner (str): This signifies the Outgoing Label information.
			Reachability (bool): This specifies whether the queried MEP could be reached or not, Yes or No.
			ReturnCode (str): This signifies the value of the return code in the Echo reply message.
			ReturnSubcode (number): This signifies the value of the return sub-code in the Echo reply message.
			ReversePathVerificationCode (str): This Signifies the reverse path verification code received in the lsp ping echo reply message.
			Rtt (str): This signifies the Round Trip Time.
			SenderHandle (number): This signifies the sender handle information.
			SequenceNumber (number): This signifies the sequence number for the ping learned information.
			Type (str): This signifies the type of the learned info.

		Returns:
			self: This instance with matching pingLearnedInfo data retrieved from the server available through an iterator or index

		Raises:
			ServerError: The server has encountered an uncategorized error condition
		"""
		return self._select(locals())

	def read(self, href):
		"""Retrieves a single instance of pingLearnedInfo data from the server.

		Args:
			href (str): An href to the instance to be retrieved

		Returns:
			self: This instance with the pingLearnedInfo data from the server available through an iterator or index

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		return self._read(href)



# MIT LICENSE
#
# Copyright 1997 - 2019 by IXIA Keysight
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"),
# to deal in the Software without restriction, including without limitation
# the rights to use, copy, modify, merge, publish, distribute, sublicense,
# and/or sell copies of the Software, and to permit persons to whom the
# Software is furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in
# all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
# THE SOFTWARE.
from ixnetwork_restpy.base import Base
from ixnetwork_restpy.files import Files


class DceNodeIpv4Groups(Base):
	"""The DceNodeIpv4Groups class encapsulates a user managed dceNodeIpv4Groups node in the ixnetwork hierarchy.

	An instance of the class can be obtained by accessing the DceNodeIpv4Groups property from a parent instance.
	The internal properties list will be empty when the property is accessed and is populated from the server using the find method.
	The internal properties list can be managed by the user by using the add and remove methods.
	"""

	_SDM_NAME = 'dceNodeIpv4Groups'

	def __init__(self, parent):
		super(DceNodeIpv4Groups, self).__init__(parent)

	@property
	def IncludeIpv4Groups(self):
		"""If true, includes IPv4 groups for this Network Range.

		Returns:
			bool
		"""
		return self._get_attribute('includeIpv4Groups')
	@IncludeIpv4Groups.setter
	def IncludeIpv4Groups(self, value):
		self._set_attribute('includeIpv4Groups', value)

	@property
	def InterGroupUnicastIpv4Increment(self):
		"""The IPv4 address format of the Unicast IPv4 between one or more node groups.

		Returns:
			str
		"""
		return self._get_attribute('interGroupUnicastIpv4Increment')
	@InterGroupUnicastIpv4Increment.setter
	def InterGroupUnicastIpv4Increment(self, value):
		self._set_attribute('interGroupUnicastIpv4Increment', value)

	@property
	def IntraGroupUnicastIpv4Increment(self):
		"""The IPv4 address format of the Unicast MAC within a node group.

		Returns:
			str
		"""
		return self._get_attribute('intraGroupUnicastIpv4Increment')
	@IntraGroupUnicastIpv4Increment.setter
	def IntraGroupUnicastIpv4Increment(self, value):
		self._set_attribute('intraGroupUnicastIpv4Increment', value)

	@property
	def MulticastAddressNodeStep(self):
		"""The Multicast IPv4 address that configures the increment across the Network Range simulated RBridges.

		Returns:
			str
		"""
		return self._get_attribute('multicastAddressNodeStep')
	@MulticastAddressNodeStep.setter
	def MulticastAddressNodeStep(self, value):
		self._set_attribute('multicastAddressNodeStep', value)

	@property
	def MulticastIpv4Count(self):
		"""The number of Multicast IPv4 addresses.

		Returns:
			number
		"""
		return self._get_attribute('multicastIpv4Count')
	@MulticastIpv4Count.setter
	def MulticastIpv4Count(self, value):
		self._set_attribute('multicastIpv4Count', value)

	@property
	def MulticastIpv4Step(self):
		"""The incremental value of Multicast IPv4 address.

		Returns:
			str
		"""
		return self._get_attribute('multicastIpv4Step')
	@MulticastIpv4Step.setter
	def MulticastIpv4Step(self, value):
		self._set_attribute('multicastIpv4Step', value)

	@property
	def NoOfUnicastScrIpv4sPerMulicastIpv4(self):
		"""The number of Unicast Source for each Multicast IPv4 address.

		Returns:
			number
		"""
		return self._get_attribute('noOfUnicastScrIpv4sPerMulicastIpv4')
	@NoOfUnicastScrIpv4sPerMulicastIpv4.setter
	def NoOfUnicastScrIpv4sPerMulicastIpv4(self, value):
		self._set_attribute('noOfUnicastScrIpv4sPerMulicastIpv4', value)

	@property
	def SourceGroupMapping(self):
		"""The Source Group mapping type.

		Returns:
			str(fullyMeshed|oneToOne|manualMapping)
		"""
		return self._get_attribute('sourceGroupMapping')
	@SourceGroupMapping.setter
	def SourceGroupMapping(self, value):
		self._set_attribute('sourceGroupMapping', value)

	@property
	def StartMulticastIpv4(self):
		"""The IP address format of the starting Multicast IPv4 address.

		Returns:
			str
		"""
		return self._get_attribute('startMulticastIpv4')
	@StartMulticastIpv4.setter
	def StartMulticastIpv4(self, value):
		self._set_attribute('startMulticastIpv4', value)

	@property
	def StartUnicastSourceIpv4(self):
		"""The IPv4 address format of the starting Unicast Source IPv4.

		Returns:
			str
		"""
		return self._get_attribute('startUnicastSourceIpv4')
	@StartUnicastSourceIpv4.setter
	def StartUnicastSourceIpv4(self, value):
		self._set_attribute('startUnicastSourceIpv4', value)

	@property
	def UnicastAddressNodeStep(self):
		"""The Unicast IPv4 address that configures the increment across the Network Range simulated RBridges.

		Returns:
			str
		"""
		return self._get_attribute('unicastAddressNodeStep')
	@UnicastAddressNodeStep.setter
	def UnicastAddressNodeStep(self, value):
		self._set_attribute('unicastAddressNodeStep', value)

	@property
	def VlanId(self):
		"""The VLAN ID of the enabled Multicast IPv4 Range.

		Returns:
			number
		"""
		return self._get_attribute('vlanId')
	@VlanId.setter
	def VlanId(self, value):
		self._set_attribute('vlanId', value)

	def update(self, IncludeIpv4Groups=None, InterGroupUnicastIpv4Increment=None, IntraGroupUnicastIpv4Increment=None, MulticastAddressNodeStep=None, MulticastIpv4Count=None, MulticastIpv4Step=None, NoOfUnicastScrIpv4sPerMulicastIpv4=None, SourceGroupMapping=None, StartMulticastIpv4=None, StartUnicastSourceIpv4=None, UnicastAddressNodeStep=None, VlanId=None):
		"""Updates a child instance of dceNodeIpv4Groups on the server.

		Args:
			IncludeIpv4Groups (bool): If true, includes IPv4 groups for this Network Range.
			InterGroupUnicastIpv4Increment (str): The IPv4 address format of the Unicast IPv4 between one or more node groups.
			IntraGroupUnicastIpv4Increment (str): The IPv4 address format of the Unicast MAC within a node group.
			MulticastAddressNodeStep (str): The Multicast IPv4 address that configures the increment across the Network Range simulated RBridges.
			MulticastIpv4Count (number): The number of Multicast IPv4 addresses.
			MulticastIpv4Step (str): The incremental value of Multicast IPv4 address.
			NoOfUnicastScrIpv4sPerMulicastIpv4 (number): The number of Unicast Source for each Multicast IPv4 address.
			SourceGroupMapping (str(fullyMeshed|oneToOne|manualMapping)): The Source Group mapping type.
			StartMulticastIpv4 (str): The IP address format of the starting Multicast IPv4 address.
			StartUnicastSourceIpv4 (str): The IPv4 address format of the starting Unicast Source IPv4.
			UnicastAddressNodeStep (str): The Unicast IPv4 address that configures the increment across the Network Range simulated RBridges.
			VlanId (number): The VLAN ID of the enabled Multicast IPv4 Range.

		Raises:
			ServerError: The server has encountered an uncategorized error condition
		"""
		self._update(locals())

	def add(self, IncludeIpv4Groups=None, InterGroupUnicastIpv4Increment=None, IntraGroupUnicastIpv4Increment=None, MulticastAddressNodeStep=None, MulticastIpv4Count=None, MulticastIpv4Step=None, NoOfUnicastScrIpv4sPerMulicastIpv4=None, SourceGroupMapping=None, StartMulticastIpv4=None, StartUnicastSourceIpv4=None, UnicastAddressNodeStep=None, VlanId=None):
		"""Adds a new dceNodeIpv4Groups node on the server and retrieves it in this instance.

		Args:
			IncludeIpv4Groups (bool): If true, includes IPv4 groups for this Network Range.
			InterGroupUnicastIpv4Increment (str): The IPv4 address format of the Unicast IPv4 between one or more node groups.
			IntraGroupUnicastIpv4Increment (str): The IPv4 address format of the Unicast MAC within a node group.
			MulticastAddressNodeStep (str): The Multicast IPv4 address that configures the increment across the Network Range simulated RBridges.
			MulticastIpv4Count (number): The number of Multicast IPv4 addresses.
			MulticastIpv4Step (str): The incremental value of Multicast IPv4 address.
			NoOfUnicastScrIpv4sPerMulicastIpv4 (number): The number of Unicast Source for each Multicast IPv4 address.
			SourceGroupMapping (str(fullyMeshed|oneToOne|manualMapping)): The Source Group mapping type.
			StartMulticastIpv4 (str): The IP address format of the starting Multicast IPv4 address.
			StartUnicastSourceIpv4 (str): The IPv4 address format of the starting Unicast Source IPv4.
			UnicastAddressNodeStep (str): The Unicast IPv4 address that configures the increment across the Network Range simulated RBridges.
			VlanId (number): The VLAN ID of the enabled Multicast IPv4 Range.

		Returns:
			self: This instance with all currently retrieved dceNodeIpv4Groups data using find and the newly added dceNodeIpv4Groups data available through an iterator or index

		Raises:
			ServerError: The server has encountered an uncategorized error condition
		"""
		return self._create(locals())

	def remove(self):
		"""Deletes all the dceNodeIpv4Groups data in this instance from server.

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		self._delete()

	def find(self, IncludeIpv4Groups=None, InterGroupUnicastIpv4Increment=None, IntraGroupUnicastIpv4Increment=None, MulticastAddressNodeStep=None, MulticastIpv4Count=None, MulticastIpv4Step=None, NoOfUnicastScrIpv4sPerMulicastIpv4=None, SourceGroupMapping=None, StartMulticastIpv4=None, StartUnicastSourceIpv4=None, UnicastAddressNodeStep=None, VlanId=None):
		"""Finds and retrieves dceNodeIpv4Groups data from the server.

		All named parameters support regex and can be used to selectively retrieve dceNodeIpv4Groups data from the server.
		By default the find method takes no parameters and will retrieve all dceNodeIpv4Groups data from the server.

		Args:
			IncludeIpv4Groups (bool): If true, includes IPv4 groups for this Network Range.
			InterGroupUnicastIpv4Increment (str): The IPv4 address format of the Unicast IPv4 between one or more node groups.
			IntraGroupUnicastIpv4Increment (str): The IPv4 address format of the Unicast MAC within a node group.
			MulticastAddressNodeStep (str): The Multicast IPv4 address that configures the increment across the Network Range simulated RBridges.
			MulticastIpv4Count (number): The number of Multicast IPv4 addresses.
			MulticastIpv4Step (str): The incremental value of Multicast IPv4 address.
			NoOfUnicastScrIpv4sPerMulicastIpv4 (number): The number of Unicast Source for each Multicast IPv4 address.
			SourceGroupMapping (str(fullyMeshed|oneToOne|manualMapping)): The Source Group mapping type.
			StartMulticastIpv4 (str): The IP address format of the starting Multicast IPv4 address.
			StartUnicastSourceIpv4 (str): The IPv4 address format of the starting Unicast Source IPv4.
			UnicastAddressNodeStep (str): The Unicast IPv4 address that configures the increment across the Network Range simulated RBridges.
			VlanId (number): The VLAN ID of the enabled Multicast IPv4 Range.

		Returns:
			self: This instance with matching dceNodeIpv4Groups data retrieved from the server available through an iterator or index

		Raises:
			ServerError: The server has encountered an uncategorized error condition
		"""
		return self._select(locals())

	def read(self, href):
		"""Retrieves a single instance of dceNodeIpv4Groups data from the server.

		Args:
			href (str): An href to the instance to be retrieved

		Returns:
			self: This instance with the dceNodeIpv4Groups data from the server available through an iterator or index

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		return self._read(href)



# MIT LICENSE
#
# Copyright 1997 - 2019 by IXIA Keysight
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"),
# to deal in the Software without restriction, including without limitation
# the rights to use, copy, modify, merge, publish, distribute, sublicense,
# and/or sell copies of the Software, and to permit persons to whom the
# Software is furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in
# all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
# THE SOFTWARE.
from ixnetwork_restpy.base import Base
from ixnetwork_restpy.files import Files


class ReceivedLabel(Base):
	"""The ReceivedLabel class encapsulates a system managed receivedLabel node in the ixnetwork hierarchy.

	An instance of the class can be obtained by accessing the ReceivedLabel property from a parent instance.
	The internal properties list will be empty when the property is accessed and is populated from the server by using the find method.
	"""

	_SDM_NAME = 'receivedLabel'

	def __init__(self, parent):
		super(ReceivedLabel, self).__init__(parent)

	@property
	def CurrentLspOrSubLspUpTime(self):
		"""Indicates the re-optimization time per LSP/Sub LSP in port level.

		Returns:
			number
		"""
		return self._get_attribute('currentLspOrSubLspUpTime')

	@property
	def DestinationIp(self):
		"""The destination router's IP address.

		Returns:
			str
		"""
		return self._get_attribute('destinationIp')

	@property
	def Label(self):
		"""Label value received from the DUT for the LSP/Tunnel ID, in response to a Label Request from the Ixia-emulated router.

		Returns:
			number
		"""
		return self._get_attribute('label')

	@property
	def LeafIp(self):
		"""IP of the leaf range.

		Returns:
			str
		"""
		return self._get_attribute('leafIp')

	@property
	def LspId(self):
		"""A unique LSP tunnel ID.

		Returns:
			number
		"""
		return self._get_attribute('lspId')

	@property
	def LspOrSubLspSetupTime(self):
		"""Indicates the set up time per LSP/Sub LSP in port level.

		Returns:
			number
		"""
		return self._get_attribute('lspOrSubLspSetupTime')

	@property
	def ReservationState(self):
		"""The reservation state after there is a graceful restart. This is not applicable for Ingress and will be equal to None.

		Returns:
			str
		"""
		return self._get_attribute('reservationState')

	@property
	def SourceIp(self):
		"""The source router's IP address.

		Returns:
			str
		"""
		return self._get_attribute('sourceIp')

	@property
	def TunnelId(self):
		"""A unique tunnel ID.

		Returns:
			number
		"""
		return self._get_attribute('tunnelId')

	@property
	def Type(self):
		"""Tunnel type, one of P2P or P2MP.

		Returns:
			str
		"""
		return self._get_attribute('type')

	def find(self, CurrentLspOrSubLspUpTime=None, DestinationIp=None, Label=None, LeafIp=None, LspId=None, LspOrSubLspSetupTime=None, ReservationState=None, SourceIp=None, TunnelId=None, Type=None):
		"""Finds and retrieves receivedLabel data from the server.

		All named parameters support regex and can be used to selectively retrieve receivedLabel data from the server.
		By default the find method takes no parameters and will retrieve all receivedLabel data from the server.

		Args:
			CurrentLspOrSubLspUpTime (number): Indicates the re-optimization time per LSP/Sub LSP in port level.
			DestinationIp (str): The destination router's IP address.
			Label (number): Label value received from the DUT for the LSP/Tunnel ID, in response to a Label Request from the Ixia-emulated router.
			LeafIp (str): IP of the leaf range.
			LspId (number): A unique LSP tunnel ID.
			LspOrSubLspSetupTime (number): Indicates the set up time per LSP/Sub LSP in port level.
			ReservationState (str): The reservation state after there is a graceful restart. This is not applicable for Ingress and will be equal to None.
			SourceIp (str): The source router's IP address.
			TunnelId (number): A unique tunnel ID.
			Type (str): Tunnel type, one of P2P or P2MP.

		Returns:
			self: This instance with matching receivedLabel data retrieved from the server available through an iterator or index

		Raises:
			ServerError: The server has encountered an uncategorized error condition
		"""
		return self._select(locals())

	def read(self, href):
		"""Retrieves a single instance of receivedLabel data from the server.

		Args:
			href (str): An href to the instance to be retrieved

		Returns:
			self: This instance with the receivedLabel data from the server available through an iterator or index

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		return self._read(href)



# MIT LICENSE
#
# Copyright 1997 - 2019 by IXIA Keysight
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"),
# to deal in the Software without restriction, including without limitation
# the rights to use, copy, modify, merge, publish, distribute, sublicense,
# and/or sell copies of the Software, and to permit persons to whom the
# Software is furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in
# all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
# THE SOFTWARE.
from ixnetwork_restpy.base import Base
from ixnetwork_restpy.files import Files


class TestConfig(Base):
	"""The TestConfig class encapsulates a required testConfig node in the ixnetwork hierarchy.

	An instance of the class can be obtained by accessing the TestConfig property from a parent instance.
	The internal properties list will contain one and only one set of properties which is populated when the property is accessed.
	"""

	_SDM_NAME = 'testConfig'

	def __init__(self, parent):
		super(TestConfig, self).__init__(parent)

	@property
	def ApplyMode(self):
		"""NOT DEFINED

		Returns:
			str
		"""
		return self._get_attribute('applyMode')
	@ApplyMode.setter
	def ApplyMode(self, value):
		self._set_attribute('applyMode', value)

	@property
	def AssignGroupType(self):
		"""It assigns the group type.

		Returns:
			str(accumulated|distributed)
		"""
		return self._get_attribute('assignGroupType')
	@AssignGroupType.setter
	def AssignGroupType(self, value):
		self._set_attribute('assignGroupType', value)

	@property
	def BidirectionalOptionEnabled(self):
		"""If true, allows bidirectional traffic.

		Returns:
			bool
		"""
		return self._get_attribute('bidirectionalOptionEnabled')
	@BidirectionalOptionEnabled.setter
	def BidirectionalOptionEnabled(self, value):
		self._set_attribute('bidirectionalOptionEnabled', value)

	@property
	def CalculateJitter(self):
		"""If true, calculates jitter.

		Returns:
			bool
		"""
		return self._get_attribute('calculateJitter')
	@CalculateJitter.setter
	def CalculateJitter(self, value):
		self._set_attribute('calculateJitter', value)

	@property
	def CalculateLatency(self):
		"""If true, calculates the latency.

		Returns:
			bool
		"""
		return self._get_attribute('calculateLatency')
	@CalculateLatency.setter
	def CalculateLatency(self, value):
		self._set_attribute('calculateLatency', value)

	@property
	def CountRandomFrameSize(self):
		"""If true, frame sizes are counted at random.

		Returns:
			number
		"""
		return self._get_attribute('countRandomFrameSize')
	@CountRandomFrameSize.setter
	def CountRandomFrameSize(self, value):
		self._set_attribute('countRandomFrameSize', value)

	@property
	def DelayAfterTransmit(self):
		"""Specifies the amount of delay after every transmit.

		Returns:
			number
		"""
		return self._get_attribute('delayAfterTransmit')
	@DelayAfterTransmit.setter
	def DelayAfterTransmit(self, value):
		self._set_attribute('delayAfterTransmit', value)

	@property
	def Duration(self):
		"""The duration of the test in hours, which is used to calculate the number of frames to transmit.

		Returns:
			number
		"""
		return self._get_attribute('duration')
	@Duration.setter
	def Duration(self, value):
		self._set_attribute('duration', value)

	@property
	def EnableDataIntegrity(self):
		"""If true, enables data integrity test.

		Returns:
			bool
		"""
		return self._get_attribute('enableDataIntegrity')
	@EnableDataIntegrity.setter
	def EnableDataIntegrity(self, value):
		self._set_attribute('enableDataIntegrity', value)

	@property
	def EnableLayer1Rate(self):
		"""NOT DEFINED

		Returns:
			bool
		"""
		return self._get_attribute('enableLayer1Rate')
	@EnableLayer1Rate.setter
	def EnableLayer1Rate(self, value):
		self._set_attribute('enableLayer1Rate', value)

	@property
	def EnableLeaveGroup(self):
		"""If true, the leave group is enabled.

		Returns:
			bool
		"""
		return self._get_attribute('enableLeaveGroup')
	@EnableLeaveGroup.setter
	def EnableLeaveGroup(self, value):
		self._set_attribute('enableLeaveGroup', value)

	@property
	def EnableMinFrameSize(self):
		"""If true, IxNetwork will allow the stream to use smaller packet sizes. This is achieved by reducing the size of the instrumentation tag, which will be identified by receiving ports.

		Returns:
			bool
		"""
		return self._get_attribute('enableMinFrameSize')
	@EnableMinFrameSize.setter
	def EnableMinFrameSize(self, value):
		self._set_attribute('enableMinFrameSize', value)

	@property
	def EnableMulticastLearning(self):
		"""If true, enables multicst learning.

		Returns:
			bool
		"""
		return self._get_attribute('enableMulticastLearning')
	@EnableMulticastLearning.setter
	def EnableMulticastLearning(self, value):
		self._set_attribute('enableMulticastLearning', value)

	@property
	def EnableMulticastQuerier(self):
		"""Enable Multicast Querier Settings

		Returns:
			bool
		"""
		return self._get_attribute('enableMulticastQuerier')
	@EnableMulticastQuerier.setter
	def EnableMulticastQuerier(self, value):
		self._set_attribute('enableMulticastQuerier', value)

	@property
	def EnableOldStatsForReef(self):
		"""If true, enables old statistics for Reef.

		Returns:
			bool
		"""
		return self._get_attribute('enableOldStatsForReef')
	@EnableOldStatsForReef.setter
	def EnableOldStatsForReef(self, value):
		self._set_attribute('enableOldStatsForReef', value)

	@property
	def EnforceBidirectional(self):
		"""If true, uses bidirectional traffic mapping.

		Returns:
			bool
		"""
		return self._get_attribute('enforceBidirectional')
	@EnforceBidirectional.setter
	def EnforceBidirectional(self, value):
		self._set_attribute('enforceBidirectional', value)

	@property
	def FloodedFramesEnabled(self):
		"""If true, it enables the flooded frames statistics

		Returns:
			bool
		"""
		return self._get_attribute('floodedFramesEnabled')
	@FloodedFramesEnabled.setter
	def FloodedFramesEnabled(self, value):
		self._set_attribute('floodedFramesEnabled', value)

	@property
	def ForceRegenerate(self):
		"""Initiates a forced regeneration.

		Returns:
			bool
		"""
		return self._get_attribute('forceRegenerate')
	@ForceRegenerate.setter
	def ForceRegenerate(self, value):
		self._set_attribute('forceRegenerate', value)

	@property
	def FrameSizeMode(self):
		"""This attribute is the frame size mode for the Quad Gaussian.

		Returns:
			str(custom|increment|random)
		"""
		return self._get_attribute('frameSizeMode')
	@FrameSizeMode.setter
	def FrameSizeMode(self, value):
		self._set_attribute('frameSizeMode', value)

	@property
	def FramesizeList(self):
		"""List containing the frame sizes used in the test.

		Returns:
			list(str)
		"""
		return self._get_attribute('framesizeList')
	@FramesizeList.setter
	def FramesizeList(self, value):
		self._set_attribute('framesizeList', value)

	@property
	def Gap(self):
		"""The gap in transmission of frames.

		Returns:
			number
		"""
		return self._get_attribute('gap')
	@Gap.setter
	def Gap(self, value):
		self._set_attribute('gap', value)

	@property
	def GroupDistributionType(self):
		"""The type of group dsitribution for the test configuration.

		Returns:
			str(acrossHosts|acrossPorts)
		"""
		return self._get_attribute('groupDistributionType')
	@GroupDistributionType.setter
	def GroupDistributionType(self, value):
		self._set_attribute('groupDistributionType', value)

	@property
	def IgmpV1Timeout(self):
		"""The IGMPv1 timeout value.

		Returns:
			number
		"""
		return self._get_attribute('igmpV1Timeout')
	@IgmpV1Timeout.setter
	def IgmpV1Timeout(self, value):
		self._set_attribute('igmpV1Timeout', value)

	@property
	def IgmpVersion(self):
		"""It signifies the version of IGMP.

		Returns:
			number
		"""
		return self._get_attribute('igmpVersion')
	@IgmpVersion.setter
	def IgmpVersion(self, value):
		self._set_attribute('igmpVersion', value)

	@property
	def Igmpv3MessageType(self):
		"""It gives details about the igmpv3 message type in the test configuration

		Returns:
			str(exclude|include)
		"""
		return self._get_attribute('igmpv3MessageType')
	@Igmpv3MessageType.setter
	def Igmpv3MessageType(self, value):
		self._set_attribute('igmpv3MessageType', value)

	@property
	def Igmpv3SourceAddrList(self):
		"""It gives details about the igmpv3 source address list in the test configuration

		Returns:
			str
		"""
		return self._get_attribute('igmpv3SourceAddrList')
	@Igmpv3SourceAddrList.setter
	def Igmpv3SourceAddrList(self, value):
		self._set_attribute('igmpv3SourceAddrList', value)

	@property
	def IncrAddresses(self):
		"""If true, the MAC address is incremented.

		Returns:
			str
		"""
		return self._get_attribute('incrAddresses')
	@IncrAddresses.setter
	def IncrAddresses(self, value):
		self._set_attribute('incrAddresses', value)

	@property
	def Ipv4Address(self):
		"""It signifies the IP address for version 4.

		Returns:
			str
		"""
		return self._get_attribute('ipv4Address')
	@Ipv4Address.setter
	def Ipv4Address(self, value):
		self._set_attribute('ipv4Address', value)

	@property
	def Ipv6Address(self):
		"""It signifies the IP address for version 6.

		Returns:
			str
		"""
		return self._get_attribute('ipv6Address')
	@Ipv6Address.setter
	def Ipv6Address(self, value):
		self._set_attribute('ipv6Address', value)

	@property
	def IsIPv6(self):
		"""Indicates if the address is an IPv6 address.

		Returns:
			str
		"""
		return self._get_attribute('isIPv6')
	@IsIPv6.setter
	def IsIPv6(self, value):
		self._set_attribute('isIPv6', value)

	@property
	def IsMulticastAutomaticFrameData(self):
		"""ndicates if the config is multicast automatic frame data.

		Returns:
			str
		"""
		return self._get_attribute('isMulticastAutomaticFrameData')
	@IsMulticastAutomaticFrameData.setter
	def IsMulticastAutomaticFrameData(self, value):
		self._set_attribute('isMulticastAutomaticFrameData', value)

	@property
	def JoinLeaveMultiplier(self):
		"""NOT DEFINED

		Returns:
			number
		"""
		return self._get_attribute('joinLeaveMultiplier')
	@JoinLeaveMultiplier.setter
	def JoinLeaveMultiplier(self, value):
		self._set_attribute('joinLeaveMultiplier', value)

	@property
	def JoinLeaveRate(self):
		"""It signifies the join and leave rate.

		Returns:
			number
		"""
		return self._get_attribute('joinLeaveRate')
	@JoinLeaveRate.setter
	def JoinLeaveRate(self, value):
		self._set_attribute('joinLeaveRate', value)

	@property
	def JoinLeaveWaitTime(self):
		"""The wait time for thr leave.

		Returns:
			number
		"""
		return self._get_attribute('joinLeaveWaitTime')
	@JoinLeaveWaitTime.setter
	def JoinLeaveWaitTime(self, value):
		self._set_attribute('joinLeaveWaitTime', value)

	@property
	def LatencyBins(self):
		"""DEPRECATED Sets the latency bins statistics

		Returns:
			str
		"""
		return self._get_attribute('latencyBins')
	@LatencyBins.setter
	def LatencyBins(self, value):
		self._set_attribute('latencyBins', value)

	@property
	def LatencyBinsEnabled(self):
		"""DEPRECATED Enables the latency bins statistics

		Returns:
			bool
		"""
		return self._get_attribute('latencyBinsEnabled')
	@LatencyBinsEnabled.setter
	def LatencyBinsEnabled(self, value):
		self._set_attribute('latencyBinsEnabled', value)

	@property
	def LatencyType(self):
		"""DEPRECATED The type of latency.

		Returns:
			str(cutThrough|storeForward)
		"""
		return self._get_attribute('latencyType')
	@LatencyType.setter
	def LatencyType(self, value):
		self._set_attribute('latencyType', value)

	@property
	def LoadInitialRate(self):
		"""DEPRECATED loadInitialRate.

		Returns:
			number
		"""
		return self._get_attribute('loadInitialRate')
	@LoadInitialRate.setter
	def LoadInitialRate(self, value):
		self._set_attribute('loadInitialRate', value)

	@property
	def LoadType(self):
		"""DEPRECATED The type of load used to modify the variable parameter value.

		Returns:
			str(binary|combo|custom|fixed|increment|quickSearch|random|step|unchanged)
		"""
		return self._get_attribute('loadType')
	@LoadType.setter
	def LoadType(self, value):
		self._set_attribute('loadType', value)

	@property
	def LoadUnit(self):
		"""DEPRECATED The load unit value.

		Returns:
			str(bpsRate|fpsRate|gbpsRate|gBpsRate|kbpsRate|kBpsRate|mbpsRate|mBpsRate|percentMaxRate)
		"""
		return self._get_attribute('loadUnit')
	@LoadUnit.setter
	def LoadUnit(self, value):
		self._set_attribute('loadUnit', value)

	@property
	def MapType(self):
		"""DEPRECATED The test configuration map type.

		Returns:
			str
		"""
		return self._get_attribute('mapType')
	@MapType.setter
	def MapType(self, value):
		self._set_attribute('mapType', value)

	@property
	def MaxIncrementFrameSize(self):
		"""DEPRECATED The integer that states the maximum amount to which the frame size can be incremented.

		Returns:
			number
		"""
		return self._get_attribute('maxIncrementFrameSize')
	@MaxIncrementFrameSize.setter
	def MaxIncrementFrameSize(self, value):
		self._set_attribute('maxIncrementFrameSize', value)

	@property
	def MaxRandomFrameSize(self):
		"""DEPRECATED The integer that states the maximum random amount to which the frame size can be incremented.

		Returns:
			number
		"""
		return self._get_attribute('maxRandomFrameSize')
	@MaxRandomFrameSize.setter
	def MaxRandomFrameSize(self, value):
		self._set_attribute('maxRandomFrameSize', value)

	@property
	def MinIncrementFrameSize(self):
		"""DEPRECATED The integer that states the minimum amount to which the frame size can be incremented.

		Returns:
			number
		"""
		return self._get_attribute('minIncrementFrameSize')
	@MinIncrementFrameSize.setter
	def MinIncrementFrameSize(self, value):
		self._set_attribute('minIncrementFrameSize', value)

	@property
	def MinRandomFrameSize(self):
		"""DEPRECATED The integer that states the minimum random amount to which the frame size can be incremented.

		Returns:
			number
		"""
		return self._get_attribute('minRandomFrameSize')
	@MinRandomFrameSize.setter
	def MinRandomFrameSize(self, value):
		self._set_attribute('minRandomFrameSize', value)

	@property
	def MldVersion(self):
		"""DEPRECATED It signifies the MLD version.

		Returns:
			number
		"""
		return self._get_attribute('mldVersion')
	@MldVersion.setter
	def MldVersion(self, value):
		self._set_attribute('mldVersion', value)

	@property
	def NumAddresses(self):
		"""DEPRECATED It signifies the number address.

		Returns:
			number
		"""
		return self._get_attribute('numAddresses')
	@NumAddresses.setter
	def NumAddresses(self, value):
		self._set_attribute('numAddresses', value)

	@property
	def NumIterations(self):
		"""DEPRECATED The integer value for the number of iterations.

		Returns:
			number
		"""
		return self._get_attribute('numIterations')
	@NumIterations.setter
	def NumIterations(self, value):
		self._set_attribute('numIterations', value)

	@property
	def Numtrials(self):
		"""DEPRECATED Defines how many times each frame size will be tested.

		Returns:
			number
		"""
		return self._get_attribute('numtrials')
	@Numtrials.setter
	def Numtrials(self, value):
		self._set_attribute('numtrials', value)

	@property
	def PortDelayEnabled(self):
		"""DEPRECATED NOT DEFINED

		Returns:
			bool
		"""
		return self._get_attribute('portDelayEnabled')
	@PortDelayEnabled.setter
	def PortDelayEnabled(self, value):
		self._set_attribute('portDelayEnabled', value)

	@property
	def PortDelayUnit(self):
		"""DEPRECATED Sets the port delay unit in which it will be measured

		Returns:
			str(bytes|nanoseconds)
		"""
		return self._get_attribute('portDelayUnit')
	@PortDelayUnit.setter
	def PortDelayUnit(self, value):
		self._set_attribute('portDelayUnit', value)

	@property
	def PortDelayValue(self):
		"""DEPRECATED Sets the port delay value

		Returns:
			number
		"""
		return self._get_attribute('portDelayValue')
	@PortDelayValue.setter
	def PortDelayValue(self, value):
		self._set_attribute('portDelayValue', value)

	@property
	def ProtocolItem(self):
		"""DEPRECATED Protocol Items

		Returns:
			list(str[None|/api/v1/sessions/1/ixnetwork/vport|/api/v1/sessions/1/ixnetwork/vport?deepchild=lan])
		"""
		return self._get_attribute('protocolItem')
	@ProtocolItem.setter
	def ProtocolItem(self, value):
		self._set_attribute('protocolItem', value)

	@property
	def ReportSequenceError(self):
		"""DEPRECATED Reports sequence errors in the test result.

		Returns:
			bool
		"""
		return self._get_attribute('reportSequenceError')
	@ReportSequenceError.setter
	def ReportSequenceError(self, value):
		self._set_attribute('reportSequenceError', value)

	@property
	def ReportTputRateUnit(self):
		"""DEPRECATED Report identifying the unit for measuring the throughput rate in frames per second.

		Returns:
			str(gbps|gBps|kbps|kBps|mbps|mBps)
		"""
		return self._get_attribute('reportTputRateUnit')
	@ReportTputRateUnit.setter
	def ReportTputRateUnit(self, value):
		self._set_attribute('reportTputRateUnit', value)

	@property
	def RouterAlert(self):
		"""DEPRECATED Sets the IP header Send Router Alert bit.

		Returns:
			bool
		"""
		return self._get_attribute('routerAlert')
	@RouterAlert.setter
	def RouterAlert(self, value):
		self._set_attribute('routerAlert', value)

	@property
	def StepIncrementFrameSize(self):
		"""DEPRECATED The step to increment the frame size.

		Returns:
			number
		"""
		return self._get_attribute('stepIncrementFrameSize')
	@StepIncrementFrameSize.setter
	def StepIncrementFrameSize(self, value):
		self._set_attribute('stepIncrementFrameSize', value)

	@property
	def SupportedTrafficTypes(self):
		"""DEPRECATED The list of supported traffic types.

		Returns:
			str
		"""
		return self._get_attribute('supportedTrafficTypes')
	@SupportedTrafficTypes.setter
	def SupportedTrafficTypes(self, value):
		self._set_attribute('supportedTrafficTypes', value)

	@property
	def TestTrafficType(self):
		"""DEPRECATED Test based on the type of traffic endpoint to be configured.

		Returns:
			str
		"""
		return self._get_attribute('testTrafficType')
	@TestTrafficType.setter
	def TestTrafficType(self, value):
		self._set_attribute('testTrafficType', value)

	@property
	def TxDelay(self):
		"""DEPRECATED Specifies the amount of delay after every transmit.

		Returns:
			number
		"""
		return self._get_attribute('txDelay')
	@TxDelay.setter
	def TxDelay(self, value):
		self._set_attribute('txDelay', value)

	def update(self, ApplyMode=None, AssignGroupType=None, BidirectionalOptionEnabled=None, CalculateJitter=None, CalculateLatency=None, CountRandomFrameSize=None, DelayAfterTransmit=None, Duration=None, EnableDataIntegrity=None, EnableLayer1Rate=None, EnableLeaveGroup=None, EnableMinFrameSize=None, EnableMulticastLearning=None, EnableMulticastQuerier=None, EnableOldStatsForReef=None, EnforceBidirectional=None, FloodedFramesEnabled=None, ForceRegenerate=None, FrameSizeMode=None, FramesizeList=None, Gap=None, GroupDistributionType=None, IgmpV1Timeout=None, IgmpVersion=None, Igmpv3MessageType=None, Igmpv3SourceAddrList=None, IncrAddresses=None, Ipv4Address=None, Ipv6Address=None, IsIPv6=None, IsMulticastAutomaticFrameData=None, JoinLeaveMultiplier=None, JoinLeaveRate=None, JoinLeaveWaitTime=None, LatencyBins=None, LatencyBinsEnabled=None, LatencyType=None, LoadInitialRate=None, LoadType=None, LoadUnit=None, MapType=None, MaxIncrementFrameSize=None, MaxRandomFrameSize=None, MinIncrementFrameSize=None, MinRandomFrameSize=None, MldVersion=None, NumAddresses=None, NumIterations=None, Numtrials=None, PortDelayEnabled=None, PortDelayUnit=None, PortDelayValue=None, ProtocolItem=None, ReportSequenceError=None, ReportTputRateUnit=None, RouterAlert=None, StepIncrementFrameSize=None, SupportedTrafficTypes=None, TestTrafficType=None, TxDelay=None):
		"""Updates a child instance of testConfig on the server.

		Args:
			ApplyMode (str): NOT DEFINED
			AssignGroupType (str(accumulated|distributed)): It assigns the group type.
			BidirectionalOptionEnabled (bool): If true, allows bidirectional traffic.
			CalculateJitter (bool): If true, calculates jitter.
			CalculateLatency (bool): If true, calculates the latency.
			CountRandomFrameSize (number): If true, frame sizes are counted at random.
			DelayAfterTransmit (number): Specifies the amount of delay after every transmit.
			Duration (number): The duration of the test in hours, which is used to calculate the number of frames to transmit.
			EnableDataIntegrity (bool): If true, enables data integrity test.
			EnableLayer1Rate (bool): NOT DEFINED
			EnableLeaveGroup (bool): If true, the leave group is enabled.
			EnableMinFrameSize (bool): If true, IxNetwork will allow the stream to use smaller packet sizes. This is achieved by reducing the size of the instrumentation tag, which will be identified by receiving ports.
			EnableMulticastLearning (bool): If true, enables multicst learning.
			EnableMulticastQuerier (bool): Enable Multicast Querier Settings
			EnableOldStatsForReef (bool): If true, enables old statistics for Reef.
			EnforceBidirectional (bool): If true, uses bidirectional traffic mapping.
			FloodedFramesEnabled (bool): If true, it enables the flooded frames statistics
			ForceRegenerate (bool): Initiates a forced regeneration.
			FrameSizeMode (str(custom|increment|random)): This attribute is the frame size mode for the Quad Gaussian.
			FramesizeList (list(str)): List containing the frame sizes used in the test.
			Gap (number): The gap in transmission of frames.
			GroupDistributionType (str(acrossHosts|acrossPorts)): The type of group dsitribution for the test configuration.
			IgmpV1Timeout (number): The IGMPv1 timeout value.
			IgmpVersion (number): It signifies the version of IGMP.
			Igmpv3MessageType (str(exclude|include)): It gives details about the igmpv3 message type in the test configuration
			Igmpv3SourceAddrList (str): It gives details about the igmpv3 source address list in the test configuration
			IncrAddresses (str): If true, the MAC address is incremented.
			Ipv4Address (str): It signifies the IP address for version 4.
			Ipv6Address (str): It signifies the IP address for version 6.
			IsIPv6 (str): Indicates if the address is an IPv6 address.
			IsMulticastAutomaticFrameData (str): ndicates if the config is multicast automatic frame data.
			JoinLeaveMultiplier (number): NOT DEFINED
			JoinLeaveRate (number): It signifies the join and leave rate.
			JoinLeaveWaitTime (number): The wait time for thr leave.
			LatencyBins (str): Sets the latency bins statistics
			LatencyBinsEnabled (bool): Enables the latency bins statistics
			LatencyType (str(cutThrough|storeForward)): The type of latency.
			LoadInitialRate (number): loadInitialRate.
			LoadType (str(binary|combo|custom|fixed|increment|quickSearch|random|step|unchanged)): The type of load used to modify the variable parameter value.
			LoadUnit (str(bpsRate|fpsRate|gbpsRate|gBpsRate|kbpsRate|kBpsRate|mbpsRate|mBpsRate|percentMaxRate)): The load unit value.
			MapType (str): The test configuration map type.
			MaxIncrementFrameSize (number): The integer that states the maximum amount to which the frame size can be incremented.
			MaxRandomFrameSize (number): The integer that states the maximum random amount to which the frame size can be incremented.
			MinIncrementFrameSize (number): The integer that states the minimum amount to which the frame size can be incremented.
			MinRandomFrameSize (number): The integer that states the minimum random amount to which the frame size can be incremented.
			MldVersion (number): It signifies the MLD version.
			NumAddresses (number): It signifies the number address.
			NumIterations (number): The integer value for the number of iterations.
			Numtrials (number): Defines how many times each frame size will be tested.
			PortDelayEnabled (bool): NOT DEFINED
			PortDelayUnit (str(bytes|nanoseconds)): Sets the port delay unit in which it will be measured
			PortDelayValue (number): Sets the port delay value
			ProtocolItem (list(str[None|/api/v1/sessions/1/ixnetwork/vport|/api/v1/sessions/1/ixnetwork/vport?deepchild=lan])): Protocol Items
			ReportSequenceError (bool): Reports sequence errors in the test result.
			ReportTputRateUnit (str(gbps|gBps|kbps|kBps|mbps|mBps)): Report identifying the unit for measuring the throughput rate in frames per second.
			RouterAlert (bool): Sets the IP header Send Router Alert bit.
			StepIncrementFrameSize (number): The step to increment the frame size.
			SupportedTrafficTypes (str): The list of supported traffic types.
			TestTrafficType (str): Test based on the type of traffic endpoint to be configured.
			TxDelay (number): Specifies the amount of delay after every transmit.

		Raises:
			ServerError: The server has encountered an uncategorized error condition
		"""
		self._update(locals())

	def Apply(self):
		"""Executes the apply operation on the server.

		Applies the specified Quick Test.

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = { "Arg1": self.href }
		return self._execute('apply', payload=payload, response_object=None)

	def ApplyAsync(self):
		"""Executes the applyAsync operation on the server.

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = { "Arg1": self.href }
		return self._execute('applyAsync', payload=payload, response_object=None)

	def ApplyAsyncResult(self):
		"""Executes the applyAsyncResult operation on the server.

			Returns:
				bool: 

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = { "Arg1": self.href }
		return self._execute('applyAsyncResult', payload=payload, response_object=None)

	def ApplyITWizardConfiguration(self):
		"""Executes the applyITWizardConfiguration operation on the server.

		Applies the specified Quick Test.

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = { "Arg1": self.href }
		return self._execute('applyITWizardConfiguration', payload=payload, response_object=None)

	def GenerateReport(self):
		"""Executes the generateReport operation on the server.

		Generate a PDF report for the last succesfull test run.

			Returns:
				str: This method is asynchronous and has no return value.

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = { "Arg1": self.href }
		return self._execute('generateReport', payload=payload, response_object=None)

	def Run(self, *args, **kwargs):
		"""Executes the run operation on the server.

		Starts the specified Quick Test and waits for its execution to finish.

		The IxNetwork modeling infrastructure allows for multiple method Signatures with the same name while python does not.
		The following correlates the modeling Signatures to the python *args variable length list:

		run()list

			Returns:
				list(str): This method is synchronous and returns the result of the test.

		run(InputParameters:string)list
			Args:
				args[0] is InputParameters (str): The input arguments of the test.

			Returns:
				list(str): This method is synchronous and returns the result of the test.

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = { "Arg1": self.href }
		for i in range(len(args)): payload['Arg%s' % (i + 2)] = args[i]
		for item in kwargs.items(): payload[item[0]] = item[1]
		return self._execute('run', payload=payload, response_object=None)

	def Start(self, *args, **kwargs):
		"""Executes the start operation on the server.

		Starts the specified Quick Test.

		The IxNetwork modeling infrastructure allows for multiple method Signatures with the same name while python does not.
		The following correlates the modeling Signatures to the python *args variable length list:

		start()

		start(InputParameters:string)
			Args:
				args[0] is InputParameters (str): The input arguments of the test.

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = { "Arg1": self.href }
		for i in range(len(args)): payload['Arg%s' % (i + 2)] = args[i]
		for item in kwargs.items(): payload[item[0]] = item[1]
		return self._execute('start', payload=payload, response_object=None)

	def Stop(self):
		"""Executes the stop operation on the server.

		Stops the currently running Quick Test.

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = { "Arg1": self.href }
		return self._execute('stop', payload=payload, response_object=None)

	def WaitForTest(self):
		"""Executes the waitForTest operation on the server.

		Waits for the execution of the specified Quick Test to be completed.

			Returns:
				list(str): This method is synchronous and returns the result of the test.

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = { "Arg1": self.href }
		return self._execute('waitForTest', payload=payload, response_object=None)
